@@ -21,13 +21,12 @@ import java.util.Map;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.dmn.api.definition.v1_1.DMNDiagram;
-import org.kie.workbench.common.dmn.api.definition.v1_1.DMNModelInstrumentedBase;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Definitions;
+import org.kie.workbench.common.dmn.api.definition.model.DMNDiagram;
+import org.kie.workbench.common.dmn.api.definition.model.DMNModelInstrumentedBase;
+import org.kie.workbench.common.dmn.api.definition.model.Definitions;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.graph.Edge;
-import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.Bounds;
 import org.kie.workbench.common.stunner.core.graph.content.definition.DefinitionSet;
@@ -77,7 +76,7 @@ public class DMNDiagramFactoryImplTest {
     @Test
     @SuppressWarnings("unchecked")
     public void testDefaultNameSpaces() {
-        final Diagram<Graph, Metadata> diagram = factory.build(NAME, metadata, graph);
+        final Diagram diagram = factory.build(NAME, metadata, graph);
 
         //We can safely get the first object on the iterator as we know the graph only contains one node
         final Node<View, Edge> root = (Node<View, Edge>) diagram.getGraph().nodes().iterator().next();
@@ -118,7 +117,7 @@ public class DMNDiagramFactoryImplTest {
     @Test
     @SuppressWarnings("unchecked")
     public void testModelName() {
-        final Diagram<Graph, Metadata> diagram = factory.build(NAME, metadata, graph);
+        final Diagram diagram = factory.build(NAME, metadata, graph);
 
         //We can safely get the first object on the iterator as we know the graph only contains one node
         final Node<View, Edge> root = (Node<View, Edge>) diagram.getGraph().nodes().iterator().next();
@@ -137,7 +136,7 @@ public class DMNDiagramFactoryImplTest {
         final Definitions existingDMNDefinitions = existingDMNDiagram.getDefinitions();
         existingDMNDefinitions.getName().setValue(EXISTING_NAME);
 
-        final Diagram<Graph, Metadata> newDiagram = factory.build(NAME, metadata, graph);
+        final Diagram newDiagram = factory.build(NAME, metadata, graph);
         final Node<View, Edge> newRoot = (Node<View, Edge>) newDiagram.getGraph().nodes().iterator().next();
         final DMNDiagram newDMNDiagram = (DMNDiagram) newRoot.getContent().getDefinition();
         final Definitions newDMNDefinitions = newDMNDiagram.getDefinitions();
