@@ -27,10 +27,10 @@ import com.ait.lienzo.shared.core.types.EventPropagationMode;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
-import org.kie.workbench.common.dmn.api.definition.v1_1.DMNModelInstrumentedBase;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
-import org.kie.workbench.common.dmn.api.definition.v1_1.FunctionDefinition;
-import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
+import org.kie.workbench.common.dmn.api.definition.model.DMNModelInstrumentedBase;
+import org.kie.workbench.common.dmn.api.definition.model.Expression;
+import org.kie.workbench.common.dmn.api.definition.model.FunctionDefinition;
+import org.kie.workbench.common.dmn.api.definition.model.InformationItem;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
 import org.kie.workbench.common.dmn.api.property.dmn.QName;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.function.AddParameterCommand;
@@ -253,14 +253,13 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
     public void addParameter(final Command onSuccess) {
         getExpression().get().ifPresent(e -> {
             final InformationItem parameter = new InformationItem();
-            parameter.setName(new Name("p" + e.getFormalParameter().size()));
+            parameter.setName(new Name());
 
             sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
                                           new AddParameterCommand(e,
                                                                   parameter,
                                                                   () -> {
                                                                       gridLayer.batch();
-                                                                      gridPanel.setFocus(true);
                                                                       onSuccess.execute();
                                                                   }));
         });
@@ -275,7 +274,6 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
                                                                      parameter,
                                                                      () -> {
                                                                          gridLayer.batch();
-                                                                         gridPanel.setFocus(true);
                                                                          onSuccess.execute();
                                                                      }));
         });
@@ -283,12 +281,16 @@ public class FunctionGrid extends BaseExpressionGrid<FunctionDefinition, DMNGrid
 
     @Override
     public void updateParameterName(final InformationItem parameter,
-                                    final String name) {
+                                    final String name,
+                                    final Command onSuccess) {
         getExpression().get().ifPresent(e -> {
             sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
                                           new UpdateParameterNameCommand(parameter,
                                                                          name,
-                                                                         gridLayer::batch));
+                                                                         () -> {
+                                                                             gridLayer.batch();
+                                                                             onSuccess.execute();
+                                                                         }));
         });
     }
 
