@@ -41,6 +41,7 @@ import static org.kie.workbench.common.dmn.client.editors.types.listview.dragand
 import static org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DNDListDOMHelper.asDragging;
 import static org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DNDListDOMHelper.asHover;
 import static org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DNDListDOMHelper.asNonDragging;
+import static org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DNDListDOMHelper.getCSSPaddingLeft;
 import static org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DNDListDOMHelper.getCSSTop;
 import static org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DNDListDOMHelper.getCSSWidth;
 import static org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DNDListDOMHelper.isGrip;
@@ -90,7 +91,8 @@ public class DNDListComponentView implements DNDListComponent.View {
     @Override
     public void refreshItemsPosition() {
 
-        for (final HTMLElement draggable : querySelector(getDragArea()).getVisibleDraggableElements()) {
+        final List<HTMLElement> items = querySelector(getDragArea()).getVisibleAndSortedDraggableElements();
+        for (final HTMLElement draggable : items) {
 
             final int positionY = Position.getY(draggable);
             final int positionX = Position.getX(draggable);
@@ -150,7 +152,7 @@ public class DNDListComponentView implements DNDListComponent.View {
     @Override
     public void consolidateYPosition() {
 
-        final List<HTMLElement> draggableElements = querySelector(getDragArea()).getVisibleDraggableElements();
+        final List<HTMLElement> draggableElements = querySelector(getDragArea()).getVisibleAndSortedDraggableElements();
 
         for (int i = 0; i < draggableElements.size(); i++) {
             Position.setY(draggableElements.get(i), i);
@@ -246,7 +248,7 @@ public class DNDListComponentView implements DNDListComponent.View {
     }
 
     private int getCurrentXPosition(final HTMLElement element) {
-        final int margin = getCSSWidth(element) / getLevelSize();
+        final int margin = getCSSPaddingLeft(element) / getLevelSize();
         return margin > 0 ? margin : 0;
     }
 
