@@ -20,15 +20,17 @@ import java.util.List;
 import java.util.Optional;
 import java.util.stream.Stream;
 
+import org.junit.Assume;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.dmn.api.definition.v1_1.DecisionRule;
-import org.kie.workbench.common.dmn.api.definition.v1_1.DecisionTable;
-import org.kie.workbench.common.dmn.api.definition.v1_1.InputClause;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
-import org.kie.workbench.common.dmn.api.definition.v1_1.OutputClause;
-import org.kie.workbench.common.dmn.api.definition.v1_1.UnaryTests;
+import org.kie.workbench.common.dmn.api.definition.model.DecisionRule;
+import org.kie.workbench.common.dmn.api.definition.model.DecisionTable;
+import org.kie.workbench.common.dmn.api.definition.model.InputClause;
+import org.kie.workbench.common.dmn.api.definition.model.LiteralExpression;
+import org.kie.workbench.common.dmn.api.definition.model.OutputClause;
+import org.kie.workbench.common.dmn.api.definition.model.UnaryTests;
+import org.kie.workbench.common.dmn.client.editors.expressions.types.dtable.DecisionTableDefaultValueUtilities;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.dtable.DecisionTableUIModelMapper;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.dtable.DecisionTableUIModelMapperHelper;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.dtable.InputClauseColumn;
@@ -49,6 +51,8 @@ import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridRow;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.RowNumberColumn;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNull;
+import static org.kie.workbench.common.dmn.client.widgets.grid.model.BaseHasDynamicHeightCell.DEFAULT_HEIGHT;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
@@ -75,6 +79,12 @@ public class AddOutputClauseCommandTest {
     @Mock
     private GraphCommandExecutionContext graphCommandExecutionContext;
 
+    @Mock
+    private org.uberfire.mvp.Command executeCanvasOperation;
+
+    @Mock
+    private org.uberfire.mvp.Command undoCanvasOperation;
+
     private DecisionTable dtable;
 
     private OutputClause outputClause;
@@ -85,8 +95,13 @@ public class AddOutputClauseCommandTest {
 
     private AddOutputClauseCommand command;
 
-    @Mock
-    private org.uberfire.mvp.Command canvasOperation;
+    @Before
+    public void doNotRunTestsOnJdkEleven() {
+
+        final String javaVersion = "11";
+        final String javaVersionPropertyKey = "java.version";
+        Assume.assumeFalse(System.getProperty(javaVersionPropertyKey).contains(javaVersion));
+    }
 
     @Before
     public void setUp() throws Exception {
@@ -96,7 +111,8 @@ public class AddOutputClauseCommandTest {
         this.outputClause = new OutputClause();
         this.uiModelMapper = new DecisionTableUIModelMapper(() -> uiModel,
                                                             () -> Optional.of(dtable),
-                                                            listSelector);
+                                                            listSelector,
+                                                            DEFAULT_HEIGHT);
 
         doReturn(0).when(uiRowNumberColumn).getIndex();
         doReturn(1).when(uiOutputClauseColumn).getIndex();
@@ -106,10 +122,11 @@ public class AddOutputClauseCommandTest {
         this.command = spy(new AddOutputClauseCommand(dtable,
                                                       outputClause,
                                                       uiModel,
-                                                      uiOutputClauseColumn,
+                                                      () -> uiOutputClauseColumn,
                                                       index,
                                                       uiModelMapper,
-                                                      canvasOperation));
+                                                      executeCanvasOperation,
+                                                      undoCanvasOperation));
     }
 
     @Test
@@ -147,17 +164,19 @@ public class AddOutputClauseCommandTest {
 
         // one new output column
         assertEquals(1, dtable.getOutput().size());
+        assertEquals(DecisionTableDefaultValueUtilities.OUTPUT_CLAUSE_PREFIX + "1",
+                     dtable.getOutput().get(0).getName());
 
         // first rule
         final List<LiteralExpression> outputEntriesRuleOne = dtable.getRule().get(0).getOutputEntry();
         assertEquals(1, outputEntriesRuleOne.size());
-        assertEquals(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE, outputEntriesRuleOne.get(0).getText());
+        assertEquals(DecisionTableDefaultValueUtilities.OUTPUT_CLAUSE_EXPRESSION_TEXT, outputEntriesRuleOne.get(0).getText().getValue());
         assertEquals(dtable.getRule().get(0), outputEntriesRuleOne.get(0).getParent());
 
         // second rule
         final List<LiteralExpression> outputEntriesRuleTwo = dtable.getRule().get(1).getOutputEntry();
         assertEquals(1, outputEntriesRuleTwo.size());
-        assertEquals(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE, outputEntriesRuleTwo.get(0).getText());
+        assertEquals(DecisionTableDefaultValueUtilities.OUTPUT_CLAUSE_EXPRESSION_TEXT, outputEntriesRuleTwo.get(0).getText().getValue());
         assertEquals(dtable.getRule().get(1), outputEntriesRuleTwo.get(0).getParent());
 
         assertEquals(dtable,
@@ -184,19 +203,22 @@ public class AddOutputClauseCommandTest {
                      graphCommand.execute(graphCommandExecutionContext));
 
         assertEquals(2, dtable.getOutput().size());
+        assertEquals(DecisionTableDefaultValueUtilities.OUTPUT_CLAUSE_PREFIX + "1",
+                     dtable.getOutput().get(0).getName());
+        assertNull(dtable.getOutput().get(1).getName());
 
         // first rule
         final List<LiteralExpression> outputEntriesRuleOne = dtable.getRule().get(0).getOutputEntry();
         assertEquals(2, outputEntriesRuleOne.size());
-        assertEquals(ruleOneOldOutput, outputEntriesRuleOne.get(1).getText());
-        assertEquals(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE, outputEntriesRuleOne.get(0).getText());
+        assertEquals(ruleOneOldOutput, outputEntriesRuleOne.get(1).getText().getValue());
+        assertEquals(DecisionTableDefaultValueUtilities.OUTPUT_CLAUSE_EXPRESSION_TEXT, outputEntriesRuleOne.get(0).getText().getValue());
         assertEquals(dtable.getRule().get(0), outputEntriesRuleOne.get(0).getParent());
 
         // second rule
         final List<LiteralExpression> outputEntriesRuleTwo = dtable.getRule().get(1).getOutputEntry();
         assertEquals(2, outputEntriesRuleTwo.size());
-        assertEquals(ruleTwoOldOutput, outputEntriesRuleTwo.get(1).getText());
-        assertEquals(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE, outputEntriesRuleTwo.get(0).getText());
+        assertEquals(ruleTwoOldOutput, outputEntriesRuleTwo.get(1).getText().getValue());
+        assertEquals(DecisionTableDefaultValueUtilities.OUTPUT_CLAUSE_EXPRESSION_TEXT, outputEntriesRuleTwo.get(0).getText().getValue());
         assertEquals(dtable.getRule().get(1), outputEntriesRuleTwo.get(0).getParent());
 
         assertEquals(dtable,
@@ -223,22 +245,34 @@ public class AddOutputClauseCommandTest {
                      graphCommand.execute(graphCommandExecutionContext));
 
         assertEquals(3, dtable.getOutput().size());
+        assertNull(dtable.getOutput().get(0).getName());
+        assertEquals(DecisionTableDefaultValueUtilities.OUTPUT_CLAUSE_PREFIX + "1",
+                     dtable.getOutput().get(1).getName());
+        assertNull(dtable.getOutput().get(2).getName());
 
         final List<LiteralExpression> ruleOutputs = dtable.getRule().get(0).getOutputEntry();
 
         // first rule
         assertEquals(3, ruleOutputs.size());
-        assertEquals(ruleOutputOne, ruleOutputs.get(0).getText());
-        assertEquals(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE, ruleOutputs.get(1).getText());
+        assertEquals(ruleOutputOne, ruleOutputs.get(0).getText().getValue());
+        assertEquals(DecisionTableDefaultValueUtilities.OUTPUT_CLAUSE_EXPRESSION_TEXT, ruleOutputs.get(1).getText().getValue());
         assertEquals(dtable.getRule().get(0), ruleOutputs.get(1).getParent());
-        assertEquals(ruleOutputTwo, ruleOutputs.get(2).getText());
+        assertEquals(ruleOutputTwo, ruleOutputs.get(2).getText().getValue());
 
         assertEquals(dtable,
                      outputClause.getParent());
     }
 
+    /**
+     * The test is skipped on jdk 11 due to https://issues.jboss.org/browse/DROOLS-3777
+     */
     @Test(expected = ArrayIndexOutOfBoundsException.class)
     public void testGraphCommandUndoNoOutputClauseColumns() throws Exception {
+
+        final String javaVersion = "11";
+        final String javaVersionPropertyKey = "java.version";
+        Assume.assumeFalse(System.getProperty(javaVersionPropertyKey).contains(javaVersion));
+
         makeCommand(DecisionTableUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT);
 
         dtable.getRule().add(new DecisionRule());
@@ -276,11 +310,11 @@ public class AddOutputClauseCommandTest {
 
         // first rule
         assertEquals(1, dtable.getRule().get(0).getOutputEntry().size());
-        assertEquals(ruleOneOldOutput, dtable.getRule().get(0).getOutputEntry().get(0).getText());
+        assertEquals(ruleOneOldOutput, dtable.getRule().get(0).getOutputEntry().get(0).getText().getValue());
 
         // second rule
         assertEquals(1, dtable.getRule().get(1).getOutputEntry().size());
-        assertEquals(ruleTwoOldOutput, dtable.getRule().get(1).getOutputEntry().get(0).getText());
+        assertEquals(ruleTwoOldOutput, dtable.getRule().get(1).getOutputEntry().get(0).getText().getValue());
     }
 
     @Test
@@ -303,17 +337,17 @@ public class AddOutputClauseCommandTest {
         dtable.getInput().add(new InputClause());
         dtable.getRule().add(new DecisionRule() {{
             getInputEntry().add(new UnaryTests() {{
-                setText(ruleInputValue);
+                getText().setValue(ruleInputValue);
             }});
             getOutputEntry().add(new LiteralExpression() {{
-                setText(ruleOutputValue);
+                getText().setValue(ruleOutputValue);
             }});
         }});
 
         //Graph command populates OutputEntries so overwrite with test values
         final Command<GraphCommandExecutionContext, RuleViolation> graphCommand = command.newGraphCommand(canvasHandler);
         graphCommand.execute(graphCommandExecutionContext);
-        dtable.getRule().get(0).getOutputEntry().get(0).setText(ruleOutputValue);
+        dtable.getRule().get(0).getOutputEntry().get(0).getText().setValue(ruleOutputValue);
 
         doReturn(1).when(uiInputClauseColumn).getIndex();
         doReturn(2).when(uiOutputClauseColumn).getIndex();
@@ -333,8 +367,8 @@ public class AddOutputClauseCommandTest {
                      canvasAddOutputClauseCommand.undo(canvasHandler));
         assertEquals(2, uiModel.getColumnCount());
 
-        // one time in execute(), one time in undo()
-        verify(canvasOperation, times(2)).execute();
+        verify(executeCanvasOperation).execute();
+        verify(undoCanvasOperation).execute();
         verify(command, times(2)).updateParentInformation();
     }
 
@@ -353,8 +387,8 @@ public class AddOutputClauseCommandTest {
         //Graph command populates OutputEntries so overwrite with test values
         final Command<GraphCommandExecutionContext, RuleViolation> graphCommand = command.newGraphCommand(canvasHandler);
         graphCommand.execute(graphCommandExecutionContext);
-        dtable.getRule().get(0).getOutputEntry().get(0).setText(ruleOneOutputValue);
-        dtable.getRule().get(1).getOutputEntry().get(0).setText(ruleTwoOutputValue);
+        dtable.getRule().get(0).getOutputEntry().get(0).getText().setValue(ruleOneOutputValue);
+        dtable.getRule().get(1).getOutputEntry().get(0).getText().setValue(ruleTwoOutputValue);
 
         final Command<AbstractCanvasHandler, CanvasViolation> canvasAddOutputClauseCommand = command.newCanvasCommand(canvasHandler);
         canvasAddOutputClauseCommand.execute(canvasHandler);
@@ -370,8 +404,8 @@ public class AddOutputClauseCommandTest {
                      canvasAddOutputClauseCommand.undo(canvasHandler));
         assertEquals(1, uiModel.getColumnCount());
 
-        // one time in execute(), one time in undo()
-        verify(canvasOperation, times(2)).execute();
+        verify(executeCanvasOperation).execute();
+        verify(undoCanvasOperation).execute();
         verify(command, times(2)).updateParentInformation();
     }
 
@@ -385,15 +419,42 @@ public class AddOutputClauseCommandTest {
         // just row number column
         assertEquals(1, uiModel.getColumnCount());
 
-        verify(canvasOperation).execute();
+        verify(undoCanvasOperation).execute();
         verify(command).updateParentInformation();
     }
 
+    @Test
+    public void testComponentWidths() {
+        makeCommand(DecisionTableUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT);
+
+        final Command<GraphCommandExecutionContext, RuleViolation> graphCommand = command.newGraphCommand(canvasHandler);
+        final Command<AbstractCanvasHandler, CanvasViolation> canvasCommand = command.newCanvasCommand(canvasHandler);
+
+        //Execute
+        assertEquals(GraphCommandResultBuilder.SUCCESS,
+                     graphCommand.execute(graphCommandExecutionContext));
+        assertEquals(CanvasCommandResultBuilder.SUCCESS,
+                     canvasCommand.execute(canvasHandler));
+
+        assertEquals(dtable.getRequiredComponentWidthCount(),
+                     dtable.getComponentWidths().size());
+        assertNull(dtable.getComponentWidths().get(DecisionTableUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT));
+
+        //Undo
+        assertEquals(GraphCommandResultBuilder.SUCCESS,
+                     graphCommand.undo(graphCommandExecutionContext));
+        assertEquals(CanvasCommandResultBuilder.SUCCESS,
+                     canvasCommand.undo(canvasHandler));
+
+        assertEquals(dtable.getRequiredComponentWidthCount(),
+                     dtable.getComponentWidths().size());
+    }
+
     private void addRuleWithOutputClauseValues(String... outputClauseValues) {
         dtable.getRule().add(new DecisionRule() {{
             Stream.of(outputClauseValues).forEach(oClause -> {
                 getOutputEntry().add(new LiteralExpression() {{
-                    setText(oClause);
+                    getText().setValue(oClause);
                 }});
             });
         }});
