@@ -42,6 +42,7 @@ import org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DN
 import org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DNDListComponent;
 import org.kie.workbench.common.dmn.client.editors.types.persistence.DataTypeStore;
 import org.kie.workbench.common.dmn.client.editors.types.search.DataTypeSearchBar;
+import org.kie.workbench.common.widgets.client.kogito.IsKogito;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.InOrder;
@@ -97,6 +98,9 @@ public class DataTypeListTest {
     @Mock
     private DNDDataTypesHandler dndDataTypesHandler;
 
+    @Mock
+    private IsKogito isKogito;
+
     private DataTypeStore dataTypeStore;
 
     private DataTypeStackHash dataTypeStackHash;
@@ -104,13 +108,23 @@ public class DataTypeListTest {
     @Captor
     private ArgumentCaptor<List<DataTypeListItem>> listItemsCaptor;
 
+    @Captor
+    private ArgumentCaptor<List<HTMLElement>> htmlElementsCaptor;
+
     private DataTypeList dataTypeList;
 
     @Before
     public void setup() {
         dataTypeStore = new DataTypeStore();
         dataTypeStackHash = new DataTypeStackHash(dataTypeStore);
-        dataTypeList = spy(new DataTypeList(view, listItems, dataTypeManager, searchBar, dndListComponent, dataTypeStackHash, dndDataTypesHandler));
+        dataTypeList = spy(new DataTypeList(view,
+                                            listItems,
+                                            dataTypeManager,
+                                            searchBar,
+                                            dndListComponent,
+                                            dataTypeStackHash,
+                                            dndDataTypesHandler,
+                                            isKogito));
         when(listItems.get()).thenReturn(treeGridItem);
     }
 
@@ -124,6 +138,23 @@ public class DataTypeListTest {
         dataTypeList.setup();
 
         verify(view).init(dataTypeList);
+        verify(view).showImportDataObjectButton();
+        verify(dndDataTypesHandler).init(dataTypeList);
+        verify(dndListComponent).setOnDropItem(consumer);
+    }
+
+    @Test
+    public void testSetupViewWhenIsKogito() {
+
+        final BiConsumer<Element, Element> consumer = (a, b) -> {/* Nothing. */};
+
+        doReturn(consumer).when(dataTypeList).getOnDropDataType();
+        when(isKogito.get()).thenReturn(true);
+
+        dataTypeList.setup();
+
+        verify(view).init(dataTypeList);
+        verify(view).hideImportDataObjectButton();
         verify(dndDataTypesHandler).init(dataTypeList);
         verify(dndListComponent).setOnDropItem(consumer);
     }
@@ -333,12 +364,20 @@ public class DataTypeListTest {
         final DataTypeManager dataTypeManager3 = mock(DataTypeManager.class);
         final ArrayList<Object> items = new ArrayList<>();
         final int level = 1;
+        final HTMLElement element0 = mock(HTMLElement.class);
+        final HTMLElement element1 = mock(HTMLElement.class);
+        final HTMLElement element2 = mock(HTMLElement.class);
+        final HTMLElement element3 = mock(HTMLElement.class);
 
         when(listItem0.getLevel()).thenReturn(level);
         when(listItem0.getDataType()).thenReturn(dataType0);
+        when(listItem0.getDragAndDropElement()).thenReturn(element0);
         when(listItem1.getDataType()).thenReturn(dataType1);
+        when(listItem1.getDragAndDropElement()).thenReturn(element1);
         when(listItem2.getDataType()).thenReturn(dataType2);
+        when(listItem2.getDragAndDropElement()).thenReturn(element2);
         when(listItem3.getDataType()).thenReturn(dataType3);
+        when(listItem3.getDragAndDropElement()).thenReturn(element3);
         when(dataTypeManager.from(dataType1)).thenReturn(dataTypeManager1);
         when(dataTypeManager.from(dataType2)).thenReturn(dataTypeManager2);
         when(dataTypeManager.from(dataType3)).thenReturn(dataTypeManager3);
@@ -354,6 +393,11 @@ public class DataTypeListTest {
         verify(dataTypeManager1).withIndexedItemDefinition();
         verify(dataTypeManager2).withIndexedItemDefinition();
         verify(dataTypeManager3).withIndexedItemDefinition();
+        verify(dndListComponent).setInitialPositionY(eq(element0), htmlElementsCaptor.capture());
+
+        final List<HTMLElement> capturedElements = htmlElementsCaptor.getValue();
+        final List<HTMLElement> expectedElements = asList(element1, element2, element3);
+        assertEquals(expectedElements, capturedElements);
 
         final List<DataTypeListItem> actualItems = listItemsCaptor.getValue();
         final List<DataTypeListItem> expectedItems = asList(listItem1, listItem2, listItem3);
@@ -829,9 +873,10 @@ public class DataTypeListTest {
         doReturn(renamed).when(dataTypeList).getRenamedImportedDataTypes();
 
         final List<DataObject> imported = Arrays.asList(do1, do2, do3);
-        doReturn(extractedName1).when(dataTypeList).extractName(do1Class);
-        doReturn(extractedName2).when(dataTypeList).extractName(do2Class);
-        doReturn(extractedName3).when(dataTypeList).extractName(do3Class);
+        when(do1.getClassNameWithoutPackage()).thenReturn(extractedName1);
+        when(do2.getClassNameWithoutPackage()).thenReturn(extractedName2);
+        when(do3.getClassNameWithoutPackage()).thenReturn(extractedName3);
+
         doReturn(builtName1).when(dataTypeList).buildName(extractedName1, namesCount);
         doReturn(builtName2).when(dataTypeList).buildName(extractedName2, namesCount);
         doReturn(builtName3).when(dataTypeList).buildName(extractedName3, namesCount);
@@ -840,19 +885,19 @@ public class DataTypeListTest {
 
         dataTypeList.removeFullQualifiedNames(imported);
 
-        verify(dataTypeList).extractName(do1Class);
+        verify(do1).getClassNameWithoutPackage();
         verify(dataTypeList).buildName(extractedName1, namesCount);
         assertTrue(renamed.containsKey(do1Class));
         assertEquals(builtName1, renamed.get(do1Class));
         verify(do1).setClassType(builtName1);
 
-        verify(dataTypeList).extractName(do2Class);
+        verify(do2).getClassNameWithoutPackage();
         verify(dataTypeList).buildName(extractedName2, namesCount);
         assertTrue(renamed.containsKey(do2Class));
         assertEquals(builtName2, renamed.get(do2Class));
         verify(do2).setClassType(builtName2);
 
-        verify(dataTypeList).extractName(do3Class);
+        verify(do3).getClassNameWithoutPackage();
         verify(dataTypeList).buildName(extractedName3, namesCount);
         assertTrue(renamed.containsKey(do3Class));
         assertEquals(builtName3, renamed.get(do3Class));
@@ -869,22 +914,6 @@ public class DataTypeListTest {
         return dataObject;
     }
 
-    @Test
-    public void testExtractName() {
-
-        final String name1 = "org.java.SomeClass";
-        final String expected1 = "SomeClass";
-
-        final String actual1 = dataTypeList.extractName(name1);
-        assertEquals(expected1, actual1);
-
-        final String name2 = "SomeOtherClass";
-        final String expected2 = "SomeOtherClass";
-
-        final String actual2 = dataTypeList.extractName(name2);
-        assertEquals(expected2, actual2);
-    }
-
     @Test
     public void testBuildName() {
 
@@ -1049,26 +1078,37 @@ public class DataTypeListTest {
         final DataTypeListItem dataTypeListItem = mock(DataTypeListItem.class);
         final DataType dataType = mock(DataType.class);
         final String uuid = "uuid";
+        final String innerUuid = "inner";
+        final String deepUuid = "deep";
 
         final DataType notChildDataType = mock(DataType.class);
         final DataTypeListItem notChildItem = mock(DataTypeListItem.class);
-        when(notChildDataType.getParentUUID()).thenReturn("other_uuid");
-        when(notChildItem.getDataType()).thenReturn(notChildDataType);
-
         final DataType childDataType1 = mock(DataType.class);
         final DataTypeListItem child1 = mock(DataTypeListItem.class);
-        when(child1.getDataType()).thenReturn(childDataType1);
-        when(childDataType1.getParentUUID()).thenReturn(uuid);
-
         final DataType childDataType2 = mock(DataType.class);
         final DataTypeListItem child2 = mock(DataTypeListItem.class);
+        final DataType innerDataType = mock(DataType.class);
+        final DataTypeListItem innerDataTypeListItem = mock(DataTypeListItem.class);
+
+        final DataType deepDataType = mock(DataType.class);
+        final DataTypeListItem deepDataTypeListItem = mock(DataTypeListItem.class);
+        when(deepDataType.getUUID()).thenReturn(deepUuid);
+        when(deepDataType.getParentUUID()).thenReturn(innerUuid);
+        when(deepDataTypeListItem.getDataType()).thenReturn(deepDataType);
+
+        when(innerDataType.getUUID()).thenReturn(innerUuid);
+        when(innerDataType.getParentUUID()).thenReturn(uuid);
+        when(innerDataTypeListItem.getDataType()).thenReturn(innerDataType);
+        when(notChildDataType.getParentUUID()).thenReturn("other_uuid");
+        when(notChildItem.getDataType()).thenReturn(notChildDataType);
+        when(child1.getDataType()).thenReturn(childDataType1);
+        when(childDataType1.getParentUUID()).thenReturn(uuid);
         when(child2.getDataType()).thenReturn(childDataType2);
         when(childDataType2.getParentUUID()).thenReturn(uuid);
-
         when(dataType.getUUID()).thenReturn(uuid);
         when(dataTypeListItem.getDataType()).thenReturn(dataType);
 
-        final List<DataTypeListItem> list = asList(child1, notChildItem, child2);
+        final List<DataTypeListItem> list = asList(child1, notChildItem, child2, innerDataTypeListItem, deepDataTypeListItem);
 
         doReturn(list).when(dataTypeList).getItems();
 
@@ -1076,9 +1116,43 @@ public class DataTypeListTest {
 
         verify(child1).disableEditMode();
         verify(child2).disableEditMode();
+        verify(innerDataTypeListItem).disableEditMode();
+        verify(deepDataTypeListItem).disableEditMode();
         verify(notChildItem, never()).disableEditMode();
     }
 
+    @Test
+    public void testGetExistingDataTypeNames() {
+
+        final String name1 = "name1";
+        final String name2 = "name2";
+        final String name3 = "name3";
+        final DataType dataType1 = makeDataType(name1, "whatever");
+        final DataType dataType2 = makeDataType(name2, "whatever");
+        final DataType dataType3 = makeDataType(name3, "whatever");
+        final DataTypeListItem listItem1 = mock(DataTypeListItem.class);
+        final DataTypeListItem listItem2 = mock(DataTypeListItem.class);
+        final DataTypeListItem listItem3 = mock(DataTypeListItem.class);
+        final List<DataTypeListItem> items = Arrays.asList(listItem1, listItem2, listItem3);
+
+        when(dataType1.isTopLevel()).thenReturn(true);
+        when(dataType2.isTopLevel()).thenReturn(false);
+        when(dataType3.isTopLevel()).thenReturn(true);
+
+        when(listItem1.getDataType()).thenReturn(dataType1);
+        when(listItem2.getDataType()).thenReturn(dataType2);
+        when(listItem3.getDataType()).thenReturn(dataType3);
+
+        doReturn(items).when(dataTypeList).getItems();
+
+        final List<String> names = dataTypeList.getExistingDataTypesNames();
+
+        assertEquals(2, names.size());
+        assertTrue(names.contains(name1));
+        assertFalse(names.contains(name2));
+        assertTrue(names.contains(name3));
+    }
+
     private DataTypeListItem listItem(final DataType dataType) {
         final DataTypeListItem listItem = mock(DataTypeListItem.class);
         when(listItem.getDataType()).thenReturn(dataType);
