@@ -18,40 +18,51 @@ package org.kie.workbench.common.forms.dynamic.client.rendering;
 
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
+import java.util.Set;
 
 import javax.annotation.PreDestroy;
 import javax.inject.Inject;
 
 import com.google.gwt.dom.client.Document;
 import com.google.gwt.user.client.ui.IsWidget;
-import org.jboss.errai.common.client.ui.ElementWrapperWidget;
+import com.google.gwt.user.client.ui.Widget;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
+import org.kie.workbench.common.forms.adf.definitions.DynamicReadOnly;
 import org.kie.workbench.common.forms.dynamic.client.rendering.formGroups.FormGroup;
 import org.kie.workbench.common.forms.dynamic.client.rendering.formGroups.impl.configError.ConfigErrorDisplayer;
+import org.kie.workbench.common.forms.dynamic.client.rendering.util.FormsElementWrapperWidgetUtil;
 import org.kie.workbench.common.forms.dynamic.service.shared.FormRenderingContext;
 import org.kie.workbench.common.forms.dynamic.service.shared.RenderMode;
 import org.kie.workbench.common.forms.model.FieldDefinition;
 import org.kie.workbench.common.forms.processing.engine.handling.FieldChangeListener;
 import org.kie.workbench.common.forms.processing.engine.handling.FormField;
 
-public abstract class FieldRenderer<F extends FieldDefinition, FORM_GROUP extends FormGroup> {
+public abstract class FieldRenderer<F extends FieldDefinition, G extends FormGroup> {
 
     protected FormRenderingContext renderingContext;
+    protected String fieldNS;
     protected F field;
     protected FormFieldImpl formField = null;
+    private FormGroup formGroup;
     protected List<FieldChangeListener> fieldChangeListeners = new ArrayList<>();
+    private Map<String, IsWidget> partsWidgets = new HashMap<>();
 
     @Inject
-    protected ManagedInstance<FORM_GROUP> formGroupsInstance;
+    protected ManagedInstance<G> formGroupsInstance;
 
     @Inject
-    private ConfigErrorDisplayer errorDisplayer;
+    protected ConfigErrorDisplayer errorDisplayer;
 
-    public void init(FormRenderingContext renderingContext,
-                     F field) {
+    @Inject
+    protected FormsElementWrapperWidgetUtil wrapperWidgetUtil;
+
+    public void init(FormRenderingContext renderingContext, F field) {
         this.renderingContext = renderingContext;
         this.field = field;
+        this.fieldNS = renderingContext.getNamespace() + FormRenderingContext.NAMESPACE_SEPARATOR + field.getName();
         fieldChangeListeners.clear();
     }
 
@@ -64,7 +75,10 @@ public abstract class FieldRenderer<F extends FieldDefinition, FORM_GROUP extend
             return errorDisplayer;
         } else {
 
-            FormGroup formGroup = getFormGroup(renderingContext.getRenderMode());
+            formGroup = getFormGroup(renderingContext.getRenderMode());
+            
+            Map<String, Widget> formPartsWidgets = formGroup.getPartsWidgets();
+            partsWidgets.putAll(formPartsWidgets);
 
             formField = new FormFieldImpl(field,
                                           formGroup) {
@@ -73,6 +87,13 @@ public abstract class FieldRenderer<F extends FieldDefinition, FORM_GROUP extend
                     if (renderingContext.getRenderMode().equals(RenderMode.PRETTY_MODE)) {
                         return;
                     }
+                    final Object model = renderingContext.getModel();
+                    if (model instanceof DynamicReadOnly){
+                        final DynamicReadOnly.ReadOnly readonlyMode = ((DynamicReadOnly) model).getReadOnly(field.getName());
+                        if (readonlyMode == DynamicReadOnly.ReadOnly.TRUE) {
+                            readOnly = true;
+                        }
+                    }
                     FieldRenderer.this.setReadOnly(readOnly);
                 }
 
@@ -94,7 +115,9 @@ public abstract class FieldRenderer<F extends FieldDefinition, FORM_GROUP extend
 
             formField.setReadOnly(renderingContext.getRenderMode().equals(RenderMode.READ_ONLY_MODE));
 
-            return ElementWrapperWidget.getWidget(formGroup.getElement());
+            registerCustomFieldValidators(formField);
+
+            return wrapperWidgetUtil.getWidget(this, formGroup.getElement());
         }
     }
 
@@ -122,15 +145,22 @@ public abstract class FieldRenderer<F extends FieldDefinition, FORM_GROUP extend
 
     public abstract String getName();
 
-    public abstract String getSupportedCode();
-
     protected abstract void setReadOnly(boolean readOnly);
 
     protected boolean isContentValid() {
         return true;
     }
 
-    public Collection<FieldChangeListener> getFieldChangeListeners() {
+    protected void registerCustomFieldValidators(FormFieldImpl field) {
+
+    }
+
+    protected void registerFieldRendererPart(IsWidget partWidget) {
+        String partId = field.getFieldType().getTypeName();
+        this.partsWidgets.put(partId, partWidget);
+    }
+
+    private Collection<FieldChangeListener> getFieldChangeListeners() {
         return fieldChangeListeners;
     }
 
@@ -153,6 +183,25 @@ public abstract class FieldRenderer<F extends FieldDefinition, FORM_GROUP extend
 
     @PreDestroy
     public void preDestroy() {
+        wrapperWidgetUtil.clear(this);
+        partsWidgets.values().forEach(part -> part.asWidget().removeFromParent());
+        partsWidgets.clear();
         formGroupsInstance.destroyAll();
+        fieldChangeListeners.clear();
+        formField = null;
+        formGroup = null;
+        field = null;
+    }
+    
+    final public Set<String> getFieldParts() {
+        return partsWidgets.keySet();
+    }
+    
+    public Widget getFieldPartWidget(String partId) {
+        IsWidget partWidget = partsWidgets.get(partId);
+        if (partWidget != null) {
+            return partWidget.asWidget();
+        }
+        return null;
     }
 }
