@@ -17,18 +17,23 @@
 package org.kie.workbench.common.forms.editor.client.editor.rendering;
 
 import java.util.Map;
+import java.util.Set;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
 
 import com.google.gwt.user.client.ui.Widget;
 import com.google.gwtmockito.GwtMock;
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
+import org.jboss.errai.ioc.client.container.SyncBeanManager;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.forms.dynamic.client.rendering.FieldRenderer;
 import org.kie.workbench.common.forms.dynamic.client.rendering.FieldRendererManager;
+import org.kie.workbench.common.forms.editor.client.editor.FormEditorContext;
 import org.kie.workbench.common.forms.editor.client.editor.FormEditorHelper;
 import org.kie.workbench.common.forms.editor.client.editor.events.FormEditorSyncPaletteEvent;
 import org.kie.workbench.common.forms.editor.client.editor.properties.FieldPropertiesRenderer;
@@ -47,12 +52,21 @@ import org.mockito.Mock;
 import org.uberfire.ext.layout.editor.api.editor.LayoutComponent;
 import org.uberfire.ext.layout.editor.client.api.ModalConfigurationContext;
 import org.uberfire.ext.layout.editor.client.api.RenderingContext;
-import org.uberfire.ext.layout.editor.client.infra.LayoutDragComponentHelper;
 import org.uberfire.mocks.EventSourceMock;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotEquals;
+import static org.junit.Assert.assertSame;
 import static org.mockito.Matchers.any;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class EditorFieldLayoutComponentTest {
@@ -75,7 +89,7 @@ public class EditorFieldLayoutComponentTest {
     private FieldPropertiesRenderer propertiesRenderer;
 
     @Mock
-    private LayoutDragComponentHelper layoutDragComponentHelper;
+    private FormEditorContext formEditorContext;
 
     @Mock
     private EventSourceMock<FormEditorSyncPaletteEvent> syncPaletteEvent;
@@ -123,7 +137,8 @@ public class EditorFieldLayoutComponentTest {
         });
 
         formEditorHelper = spy(new FormEditorHelper(new TestFieldManager(),
-                                                    editorFieldLayoutComponents));
+                                                    editorFieldLayoutComponents,
+                                                    mock(SyncBeanManager.class)));
 
         fieldDefinition = new TextBoxFieldDefinition();
         fieldDefinition.setId(EditorFieldLayoutComponent.FIELD_ID);
@@ -156,20 +171,13 @@ public class EditorFieldLayoutComponentTest {
 
         when(propertiesRenderer.getView()).thenReturn(fieldPropertiesRendererView);
 
-        editorFieldLayoutComponent = spy(new EditorFieldLayoutComponent(propertiesRenderer,
-                                                                        layoutDragComponentHelper,
-                                                                        fieldManager,
-                                                                        syncPaletteEvent) {
-            {
-                fieldRendererManager = EditorFieldLayoutComponentTest.this.fieldRendererManager;
-                translationService = EditorFieldLayoutComponentTest.this.translationService;
-            }
+        FormEditorContext.setActiveEditorHelper(formEditorHelper);
 
-            @Override
-            protected FormEditorHelper getHelperInstance() {
-                return formEditorHelper;
-            }
-        });
+        editorFieldLayoutComponent = spy(new EditorFieldLayoutComponent(fieldRendererManager,
+                                                                        translationService,
+                                                                        propertiesRenderer,
+                                                                        fieldManager,
+                                                                        syncPaletteEvent));
 
         editorFieldLayoutComponent.initPropertiesConfig();
         propertiesRendererHelper = spy(editorFieldLayoutComponent.getPropertiesRendererHelper());
@@ -364,6 +372,7 @@ public class EditorFieldLayoutComponentTest {
         }
         if (withConfigContext) {
             when(ctx.getComponentProperties()).thenReturn(mock(Map.class));
+            when(ctx.getLayoutComponent()).thenReturn(new LayoutComponent());
             editorFieldLayoutComponent.getConfigurationModal(ctx);
         }
 
@@ -428,4 +437,19 @@ public class EditorFieldLayoutComponentTest {
         assertFalse(editorFieldLayoutComponent.showProperties);
         verify(ctx).configurationCancelled();
     }
+
+    @Test
+    public void testFieldPartsAdded() {
+        Set<String> parts = Stream.of("p1", "p2").collect(Collectors.toSet());
+        when(fieldRenderer.getFieldParts()).thenReturn(parts);
+        editorFieldLayoutComponent.generateContent(ctx);
+        editorFieldLayoutComponent.addComponentParts(ctx.getComponent());
+        Set<String> expectedParts = layoutComponent.getParts().stream().map(p -> p.getPartId()).collect(Collectors.toSet());
+        parts = Stream.of("p1", "p3").collect(Collectors.toSet());
+        when(fieldRenderer.getFieldParts()).thenReturn(parts);
+        editorFieldLayoutComponent.generateContent(ctx);
+        editorFieldLayoutComponent.addComponentParts(ctx.getComponent());
+        expectedParts = layoutComponent.getParts().stream().map(p -> p.getPartId()).collect(Collectors.toSet());
+        assertEquals(parts, expectedParts);
+    }
 }
