@@ -16,25 +16,27 @@
 
 package org.kie.workbench.common.screens.library.client.screens;
 
-import java.util.List;
 import javax.annotation.PostConstruct;
+import javax.enterprise.event.Event;
 import javax.enterprise.event.Observes;
 import javax.inject.Inject;
 
 import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.project.client.security.ProjectController;
 import org.guvnor.common.services.project.events.NewProjectEvent;
-import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.structure.client.security.OrganizationalUnitController;
 import org.guvnor.structure.contributors.SpaceContributorsUpdatedEvent;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.repositories.RepositoryRemovedEvent;
 import org.jboss.errai.common.client.api.Caller;
+import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.common.client.dom.HTMLElement;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
+import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.api.ProjectCountUpdate;
 import org.kie.workbench.common.screens.library.client.perspective.LibraryPerspective;
+import org.kie.workbench.common.screens.library.client.resources.i18n.LibraryConstants;
 import org.kie.workbench.common.screens.library.client.screens.organizationalunit.contributors.tab.ContributorsListPresenter;
 import org.kie.workbench.common.screens.library.client.screens.organizationalunit.contributors.tab.SpaceContributorsListServiceImpl;
 import org.kie.workbench.common.screens.library.client.screens.organizationalunit.delete.DeleteOrganizationalUnitPopUpPresenter;
@@ -45,12 +47,12 @@ import org.uberfire.client.annotations.WorkbenchScreen;
 import org.uberfire.client.mvp.UberElement;
 import org.uberfire.lifecycle.OnClose;
 import org.uberfire.spaces.Space;
+import org.uberfire.workbench.events.NotificationEvent;
 
 @WorkbenchScreen(identifier = LibraryPlaces.LIBRARY_SCREEN,
         owningPerspective = LibraryPerspective.class)
 public class LibraryScreen {
 
-    protected List<WorkspaceProject> projects;
     private View view;
     private ManagedInstance<DeleteOrganizationalUnitPopUpPresenter> deleteOrganizationalUnitPopUpPresenters;
     private ProjectController projectController;
@@ -64,6 +66,8 @@ public class LibraryScreen {
     private Caller<LibraryService> libraryService;
     private LibraryPlaces libraryPlaces;
     private SpaceContributorsListServiceImpl spaceContributorsListService;
+    private Event<NotificationEvent> notificationEvent;
+    private TranslationService translationService;
 
     @Inject
     public LibraryScreen(final View view,
@@ -77,7 +81,9 @@ public class LibraryScreen {
                          final ContributorsListPresenter contributorsListPresenter,
                          final Caller<LibraryService> libraryService,
                          final LibraryPlaces libraryPlaces,
-                         final SpaceContributorsListServiceImpl spaceContributorsListService) {
+                         final SpaceContributorsListServiceImpl spaceContributorsListService,
+                         final Event<NotificationEvent> notificationEvent,
+                         final TranslationService translationService) {
         this.view = view;
         this.deleteOrganizationalUnitPopUpPresenters = deleteOrganizationalUnitPopUpPresenters;
         this.projectContext = projectContext;
@@ -90,13 +96,19 @@ public class LibraryScreen {
         this.libraryService = libraryService;
         this.libraryPlaces = libraryPlaces;
         this.spaceContributorsListService = spaceContributorsListService;
+        this.notificationEvent = notificationEvent;
+        this.translationService = translationService;
     }
 
     @PostConstruct
     public void init() {
+
+        final OrganizationalUnit activeOU = projectContext.getActiveOrganizationalUnit()
+                .orElseThrow(() -> new IllegalStateException("Cannot initialize library screen without an active organizational unit."));
+
         view.init(this);
-        view.setTitle(projectContext.getActiveOrganizationalUnit()
-                              .orElseThrow(() -> new IllegalStateException("Cannot initialize library screen without an active organizational unit.")).getName());
+        view.setTitle(activeOU.getName());
+
         showProjects();
 
         contributorsListPresenter.setup(spaceContributorsListService,
@@ -114,10 +126,7 @@ public class LibraryScreen {
 
     public void importProject() {
         if (userCanCreateProjects()) {
-            libraryPlaces.closeAllPlacesOrNothing(() -> {
-                libraryPlaces.goToLibrary();
-                libraryPlaces.goToImportRepositoryPopUp();
-            });
+            libraryPlaces.goToImportRepositoryPopUp();
         }
     }
 
@@ -130,23 +139,27 @@ public class LibraryScreen {
     }
 
     public void showProjects() {
-        view.setProjectsCount(0);
         final OrganizationalUnit activeOU = projectContext.getActiveOrganizationalUnit()
                 .orElseThrow(() -> new IllegalStateException("Cannot try to query library projects without an active organizational unit."));
-        final boolean cachedHasProjects = !activeOU.getRepositories().isEmpty();
-        if (cachedHasProjects) {
+
+        this.showProjects(activeOU);
+    }
+
+    protected void showProjects(OrganizationalUnit organizationalUnit) {
+        if (organizationalUnitController.canReadOrgUnit(organizationalUnit)) {
+            libraryService.call((RemoteCallback<Boolean>) this::setLibraryProjectScreen).hasProjects(organizationalUnit);
+        } else {
+            notificationEvent.fire(new NotificationEvent(translationService.format(LibraryConstants.SpacePermissionsChanged, organizationalUnit.getName()), NotificationEvent.NotificationType.WARNING));
+            libraryPlaces.closeAllPlacesOrNothing(() -> libraryPlaces.goToOrganizationalUnits());
+        }
+    }
+
+    protected void setLibraryProjectScreen(boolean hasProjects) {
+        if (hasProjects) {
             showPopulatedLibraryScreen();
         } else {
             showEmptyLibraryScreen();
         }
-        // Now do a call and possibly update if this is different
-        libraryService.call((Boolean hasProjects) -> {
-            if (hasProjects && !cachedHasProjects) {
-                showPopulatedLibraryScreen();
-            } else if (!hasProjects && cachedHasProjects) {
-                showEmptyLibraryScreen();
-            }
-        }).hasProjects(activeOU);
     }
 
     private void showEmptyLibraryScreen() {
@@ -221,6 +234,7 @@ public class LibraryScreen {
         projectContext.getActiveOrganizationalUnit().ifPresent(p -> {
             if (eventOnCurrentSpace(p, spaceContributorsUpdatedEvent.getOrganizationalUnit().getSpace())) {
                 view.setContributorsCount(spaceContributorsUpdatedEvent.getOrganizationalUnit().getContributors().size());
+                this.showProjects(spaceContributorsUpdatedEvent.getOrganizationalUnit());
             }
         });
     }
