@@ -17,10 +17,10 @@ package org.kie.workbench.common.screens.library.client.util;
 
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.Optional;
 import java.util.Set;
 
 import javax.annotation.PostConstruct;
@@ -40,9 +40,9 @@ import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.project.service.WorkspaceProjectService;
 import org.guvnor.messageconsole.client.console.MessageConsoleScreen;
 import org.guvnor.structure.client.security.OrganizationalUnitController;
-import org.guvnor.structure.events.AfterDeleteOrganizationalUnitEvent;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
+import org.guvnor.structure.organizationalunit.RemoveOrganizationalUnitEvent;
 import org.guvnor.structure.repositories.Branch;
 import org.guvnor.structure.repositories.Repository;
 import org.guvnor.structure.repositories.RepositoryRemovedEvent;
@@ -60,17 +60,18 @@ import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.api.ProjectAssetListUpdated;
 import org.kie.workbench.common.screens.library.api.Remote;
 import org.kie.workbench.common.screens.library.api.Routed;
-import org.kie.workbench.common.screens.library.api.preferences.LibraryInternalPreferences;
 import org.kie.workbench.common.screens.library.client.events.AssetDetailEvent;
 import org.kie.workbench.common.screens.library.client.perspective.LibraryPerspective;
 import org.kie.workbench.common.screens.library.client.resources.i18n.LibraryConstants;
 import org.kie.workbench.common.screens.library.client.screens.importrepository.ImportProjectsSetupEvent;
 import org.kie.workbench.common.screens.library.client.screens.importrepository.ImportRepositoryPopUpPresenter;
 import org.kie.workbench.common.screens.library.client.screens.importrepository.Source;
+import org.kie.workbench.common.screens.library.client.screens.project.changerequest.ChangeRequestUtils;
 import org.kie.workbench.common.screens.library.client.screens.project.close.CloseUnsavedProjectAssetsPopUpPresenter;
 import org.kie.workbench.common.screens.library.client.util.breadcrumb.LibraryBreadcrumbs;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.kie.workbench.common.widgets.client.handlers.NewResourceSuccessEvent;
+import org.slf4j.Logger;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.backend.vfs.VFSService;
@@ -113,6 +114,8 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
     public static final String ALERTS = MessageConsoleScreen.ALERTS;
     public static final String REPOSITORY_STRUCTURE_SCREEN = "repositoryStructureScreen";
     public static final String ADD_ASSET_SCREEN = "AddAssetsScreen";
+    public static final String SUBMIT_CHANGE_REQUEST = "SubmitChangeRequestScreen";
+    public static final String CHANGE_REQUEST_REVIEW = "ChangeRequestReviewScreen";
 
     public static final List<String> LIBRARY_PLACES = Arrays.asList(
             LIBRARY_SCREEN,
@@ -123,6 +126,8 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
             ORGANIZATIONAL_UNITS_SCREEN,
             PROJECT_SETTINGS,
             ADD_ASSET_SCREEN,
+            SUBMIT_CHANGE_REQUEST,
+            CHANGE_REQUEST_REVIEW,
             IMPORT_PROJECTS_SCREEN,
             IMPORT_SAMPLE_PROJECTS_SCREEN,
             PreferencesRootScreen.IDENTIFIER
@@ -166,19 +171,20 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
 
     private SessionInfo sessionInfo;
 
-    private LibraryInternalPreferences libraryInternalPreferences;
-
     private Caller<RepositoryService> repositoryService;
 
     private OrganizationalUnitController organizationalUnitController;
 
-    @Inject
-    private Caller<OrganizationalUnitService> organizationalUnitService;
-
     private Promises promises;
 
+    private Caller<OrganizationalUnitService> organizationalUnitService;
+
+    private Logger logger;
+
     private boolean closingLibraryPlaces = false;
 
+    private PlaceRequest changeRequestReviewScreen = null;
+
     public LibraryPlaces() {
     }
 
@@ -201,10 +207,11 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
                          final @Source(Source.Kind.EXTERNAL) Event<ImportProjectsSetupEvent> importProjectsSetupEvent,
                          final LibraryBreadcrumbs libraryBreadcrumbs,
                          final SessionInfo sessionInfo,
-                         final LibraryInternalPreferences libraryInternalPreferences,
                          final Caller<RepositoryService> repositoryService,
                          final Promises promises,
-                         final OrganizationalUnitController organizationalUnitController) {
+                         final OrganizationalUnitController organizationalUnitController,
+                         final Caller<OrganizationalUnitService> organizationalUnitService,
+                         final Logger logger) {
 
         this.breadcrumbs = breadcrumbs;
         this.ts = ts;
@@ -224,10 +231,11 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         this.importProjectsSetupEvent = importProjectsSetupEvent;
         this.libraryBreadcrumbs = libraryBreadcrumbs;
         this.sessionInfo = sessionInfo;
-        this.libraryInternalPreferences = libraryInternalPreferences;
         this.repositoryService = repositoryService;
         this.promises = promises;
         this.organizationalUnitController = organizationalUnitController;
+        this.organizationalUnitService = organizationalUnitService;
+        this.logger = logger;
     }
 
     @PostConstruct
@@ -256,7 +264,7 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         return self.promises.promisify(self.organizationalUnitService, s -> {
             return s.getOrganizationalUnit(spaceName);
         }).then(space -> {
-            self.projectContextChangeEvent.fire(new WorkspaceProjectContextChangeEvent());
+            self.projectContextChangeEvent.fire(new WorkspaceProjectContextChangeEvent(space));
             return self.goToLibrary();
         });
     }
@@ -268,7 +276,6 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         }
     }-*/;
 
-
     public static boolean nativeUserCanCreateOrganizationalUnit() {
         return self.userCanCreateOrganizationalUnit();
     }
@@ -356,8 +363,9 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
                 .isPresent();
     }
 
-    public void onOrganizationalUnitRemoved(@Observes final AfterDeleteOrganizationalUnitEvent removedOrganizationalUnitEvent) {
-        if (isLibraryPerspectiveOpen()) {
+    public void onOrganizationalUnitRemoved(@Observes final RemoveOrganizationalUnitEvent removedOrganizationalUnitEvent) {
+        final String loggedUser = sessionInfo.getIdentity().getIdentifier();
+        if (isLibraryPerspectiveOpen() && !loggedUser.equals(removedOrganizationalUnitEvent.getUserName())) {
             projectContext.getActiveOrganizationalUnit()
                     .filter(active -> active.equals(removedOrganizationalUnitEvent.getOrganizationalUnit()))
                     .ifPresent(active -> this.goToOrganizationalUnits());
@@ -426,12 +434,7 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
             return promises.create((res, rej) -> {
                 libraryService.call(
                         (RemoteCallback<OrganizationalUnit>) organizationalUnit -> {
-                            if (organizationalUnit == null) {
-                                this.goToOrganizationalUnits();
-                            } else {
-                                projectContextChangeEvent.fire(new WorkspaceProjectContextChangeEvent(organizationalUnit));
-                                setupLibraryPerspective();
-                            }
+                            this.goToOrganizationalUnits();
                             res.onInvoke((IThenable<Void>) null);
                         },
                         (message, throwable) -> {
@@ -478,16 +481,12 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         if (projectContext.getActiveWorkspaceProject()
                 .map(activeProject -> !activeProject.equals(project))
                 .orElse(true)) {
-            libraryInternalPreferences.load(loadedLibraryInternalPreferences -> {
-                                                closeAllPlacesOrNothing(() -> {
-                                                    projectContextChangeEvent.fire(new WorkspaceProjectContextChangeEvent(project,
-                                                                                                                          project.getMainModule()));
-                                                    goToProject(project,
-                                                                loadedLibraryInternalPreferences.getLastBranchOpened(project).orElse(project.getBranch()));
-                                                });
-                                            },
-                                            error -> {
-                                            });
+            closeAllPlacesOrNothing(() -> {
+                projectContextChangeEvent.fire(new WorkspaceProjectContextChangeEvent(project,
+                                                                                      project.getMainModule()));
+                goToProject(project,
+                            project.getBranch());
+            });
         } else {
             goToProject();
         }
@@ -495,23 +494,11 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
 
     public void goToProject(final WorkspaceProject project,
                             final Branch branch) {
-        libraryInternalPreferences.load(loadedLibraryInternalPreferences -> {
-                                            final Optional<Branch> lastBranchOpened = loadedLibraryInternalPreferences.getLastBranchOpened(project);
-                                            final Command goToProjectCommand = () -> projectService.call((RemoteCallback<WorkspaceProject>) this::goToProject).resolveProject(project.getSpace(),
-                                                                                                                                                                              branch);
-
-                                            if (!lastBranchOpened.isPresent() || !lastBranchOpened.get().equals(branch)) {
-                                                loadedLibraryInternalPreferences.setLastBranchOpened(project,
-                                                                                                     branch);
-                                                loadedLibraryInternalPreferences.save(goToProjectCommand,
-                                                                                      error -> {
-                                                                                      });
-                                            } else {
-                                                goToProjectCommand.execute();
-                                            }
-                                        },
-                                        error -> {
-                                        });
+        projectService.call((RemoteCallback<WorkspaceProject>) this::goToProject,
+                            (o, throwable) -> {
+                                logger.info("Project " + project.getName() + " branch " + branch.getName() + " not found.");
+                                return false;
+                            }).resolveProject(project.getSpace(), branch);
     }
 
     void goToProject() {
@@ -562,6 +549,31 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
                           libraryPerspective.getRootPanel());
     }
 
+    public void goToSubmitChangeRequestScreen() {
+        final PlaceRequest submitChangeRequestScreen = new DefaultPlaceRequest(LibraryPlaces.SUBMIT_CHANGE_REQUEST);
+        final PartDefinitionImpl part = new PartDefinitionImpl(submitChangeRequestScreen);
+        part.setSelectable(false);
+        placeManager.goTo(part,
+                          libraryPerspective.getRootPanel());
+        libraryBreadcrumbs.setupForSubmitChangeRequest(getActiveWorkspace());
+    }
+
+    public void goToChangeRequestReviewScreen(final long changeRequestId) {
+        this.closeChangeRequestReviewScreen();
+
+        changeRequestReviewScreen =
+                new DefaultPlaceRequest(LibraryPlaces.CHANGE_REQUEST_REVIEW,
+                                        Collections.singletonMap(ChangeRequestUtils.CHANGE_REQUEST_ID_KEY,
+                                                                 String.valueOf(changeRequestId)));
+
+        final PartDefinitionImpl part = new PartDefinitionImpl(changeRequestReviewScreen);
+        part.setSelectable(false);
+        placeManager.goTo(part,
+                          libraryPerspective.getRootPanel());
+        libraryBreadcrumbs.setupForChangeRequestReview(getActiveWorkspace(),
+                                                       changeRequestId);
+    }
+
     public void goToTrySamples() {
         closeAllPlacesOrNothing(() -> {
             final DefaultPlaceRequest placeRequest = new DefaultPlaceRequest(LibraryPlaces.IMPORT_SAMPLE_PROJECTS_SCREEN);
@@ -653,6 +665,12 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         }
     }
 
+    public void closeChangeRequestReviewScreen() {
+        if (changeRequestReviewScreen != null) {
+            placeManager.closePlace(changeRequestReviewScreen);
+        }
+    }
+
     public void closePlace(final Command successCallback,
                            final PlaceRequest place) {
         final boolean canClosePlace = placeManager.canClosePlace(place);
@@ -696,9 +714,10 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         return this.projectContext.getActiveOrganizationalUnit().orElseThrow(() -> new IllegalStateException("No active space found"));
     }
 
-    public boolean isThisUserAccessingThisRepository(final User user,
+    public boolean isThisUserAccessingThisRepository(final String userIdentifier,
                                                      final Repository repository) {
-        return isThisRepositoryBeingAccessed(repository) && sessionInfo.getIdentity().equals(user);
+        return isThisRepositoryBeingAccessed(repository)
+            && sessionInfo.getIdentity().getIdentifier().equals(userIdentifier);
     }
 
     public boolean isThisRepositoryBeingAccessed(final Repository repository) {
