@@ -21,6 +21,7 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.function.Predicate;
+
 import javax.enterprise.event.Event;
 import javax.enterprise.inject.Instance;
 
@@ -33,11 +34,13 @@ import org.guvnor.common.services.backend.metadata.MetadataServerSideService;
 import org.guvnor.common.services.backend.metadata.MetadataServiceImpl;
 import org.guvnor.common.services.backend.util.CommentedOptionFactory;
 import org.guvnor.common.services.backend.util.CommentedOptionFactoryImpl;
+import org.guvnor.common.services.project.backend.server.DefaultPomEnhancer;
 import org.guvnor.common.services.project.backend.server.ModuleFinder;
 import org.guvnor.common.services.project.backend.server.ModuleRepositoriesContentHandler;
 import org.guvnor.common.services.project.backend.server.ModuleRepositoryResolverImpl;
 import org.guvnor.common.services.project.backend.server.ModuleResourcePathResolver;
 import org.guvnor.common.services.project.backend.server.POMServiceImpl;
+import org.guvnor.common.services.project.backend.server.PomEnhancer;
 import org.guvnor.common.services.project.backend.server.ProjectConfigurationContentHandler;
 import org.guvnor.common.services.project.backend.server.utils.POMContentHandler;
 import org.guvnor.common.services.project.builder.events.InvalidateDMOModuleCacheEvent;
@@ -46,9 +49,9 @@ import org.guvnor.common.services.project.builder.service.BuildValidationHelper;
 import org.guvnor.common.services.project.builder.service.PostBuildHandler;
 import org.guvnor.common.services.project.events.NewModuleEvent;
 import org.guvnor.common.services.project.events.NewPackageEvent;
-import org.guvnor.common.services.project.events.RenameModuleEvent;
 import org.guvnor.common.services.project.service.ModuleRepositoriesService;
 import org.guvnor.common.services.project.service.ModuleRepositoryResolver;
+import org.guvnor.common.services.project.service.ModuleService;
 import org.guvnor.common.services.project.service.POMService;
 import org.guvnor.common.services.shared.metadata.MetadataService;
 import org.guvnor.m2repo.backend.server.M2RepoServiceImpl;
@@ -119,9 +122,11 @@ import org.uberfire.security.authz.PermissionTypeRegistry;
 import org.uberfire.security.impl.authz.DefaultPermissionTypeRegistry;
 import org.uberfire.security.impl.authz.DotNamedPermissionType;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
 import static org.kie.workbench.common.services.datamodel.backend.server.ModuleDataModelOracleTestUtils.assertContains;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class DataModelServiceConstructorTest {
@@ -166,14 +171,20 @@ public class DataModelServiceConstructorTest {
         IOService configIOService = cfiosProducer.configIOService();
         MetadataService metadataService = new MetadataServiceImpl(ioService,
                                                                   configIOService,
+                                                                  mock(CommentedOptionFactory.class),
                                                                   sessionInfo);
 
         POMContentHandler pomContentHandler = new POMContentHandler();
         M2RepoServiceImpl m2RepoService = new M2RepoServiceImpl();
+        PomEnhancer pomEnhancer = new DefaultPomEnhancer();
         POMService pomService = new POMServiceImpl(ioService,
                                                    pomContentHandler,
                                                    m2RepoService,
-                                                   metadataService);
+                                                   metadataService,
+                                                   new EventSourceMock<>(),
+                                                   mock(ModuleService.class),
+                                                   mock(CommentedOptionFactory.class),
+                                                   pomEnhancer);
         KModuleContentHandler moduleContentHandler = new KModuleContentHandler();
 
         CommentedOptionFactory commentedOptionFactory = new CommentedOptionFactoryImpl(sessionInfo);
@@ -185,7 +196,6 @@ public class DataModelServiceConstructorTest {
 
         Event<NewModuleEvent> newModuleEvent = new EventSourceMock<>();
         Event<NewPackageEvent> newPackageEvent = new EventSourceMock<>();
-        Event<RenameModuleEvent> renameModuleEvent = new EventSourceMock<>();
         Event<InvalidateDMOModuleCacheEvent> invalidateDMOCache = new EventSourceMock<>();
 
         PermissionTypeRegistry permissionTypeRegistry = new DefaultPermissionTypeRegistry();
@@ -227,7 +237,6 @@ public class DataModelServiceConstructorTest {
                                                        repoService,
                                                        newModuleEvent,
                                                        newPackageEvent,
-                                                       renameModuleEvent,
                                                        invalidateDMOCache,
                                                        sessionInfo,
                                                        commentedOptionFactory,
@@ -248,6 +257,7 @@ public class DataModelServiceConstructorTest {
                                                                            ioService);
         MetadataServerSideService serverSideMetdataService = new MetadataServiceImpl(ioService,
                                                                                      configIOService,
+                                                                                     commentedOptionFactory,
                                                                                      sessionInfo);
         PackageNameWhiteListSaver saver = new PackageNameWhiteListSaver(ioService,
                                                                         serverSideMetdataService,
@@ -361,7 +371,7 @@ public class DataModelServiceConstructorTest {
                      oracle.getModuleTypeSources().get("t1p1.DRLBean"));
         assertEquals(TypeSource.JAVA_PROJECT,
                      oracle.getModuleTypeSources().get("t1p2.Bean2"));
-        assertEquals(TypeSource.JAVA_PROJECT,
+        assertEquals(TypeSource.JAVA_DEPENDENCY,
                      oracle.getModuleTypeSources().get("java.lang.String"));
     }
 
@@ -409,7 +419,6 @@ public class DataModelServiceConstructorTest {
                                           RepositoryService repoService,
                                           Event<NewModuleEvent> newModuleEvent,
                                           Event<NewPackageEvent> newPackageEvent,
-                                          Event<RenameModuleEvent> renameModuleEvent,
                                           Event<InvalidateDMOModuleCacheEvent> invalidateDMOCache,
                                           SessionInfo sessionInfo,
                                           CommentedOptionFactory commentedOptionFactory,
@@ -422,7 +431,6 @@ public class DataModelServiceConstructorTest {
                   repoService,
                   newModuleEvent,
                   newPackageEvent,
-                  renameModuleEvent,
                   invalidateDMOCache,
                   sessionInfo,
                   commentedOptionFactory,
