@@ -16,7 +16,6 @@
 
 package org.kie.workbench.common.stunner.client.lienzo.canvas.controls;
 
-import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Objects;
 import java.util.function.Supplier;
@@ -25,38 +24,47 @@ import java.util.stream.Collectors;
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
 import javax.enterprise.event.Observes;
+import javax.enterprise.inject.Default;
 import javax.inject.Inject;
 
 import com.ait.lienzo.client.core.shape.Shape;
+import com.ait.lienzo.client.core.shape.wires.DefaultSelectionListener;
+import com.ait.lienzo.client.core.shape.wires.SelectionListener;
 import com.ait.lienzo.client.core.shape.wires.SelectionManager;
 import com.ait.lienzo.client.core.shape.wires.WiresConnector;
 import com.ait.lienzo.client.core.shape.wires.WiresManager;
 import com.ait.lienzo.client.core.shape.wires.WiresShape;
-import com.ait.lienzo.client.core.types.BoundingBox;
 import com.ait.lienzo.client.core.types.Point2D;
 import com.google.gwt.event.dom.client.MouseEvent;
 import com.google.gwt.event.shared.EventHandler;
 import com.google.gwt.event.shared.HandlerRegistration;
+import org.kie.soup.commons.util.Lists;
 import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresCanvas;
 import org.kie.workbench.common.stunner.client.lienzo.shape.view.wires.WiresConnectorView;
 import org.kie.workbench.common.stunner.client.lienzo.shape.view.wires.WiresShapeView;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.SelectionControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.select.AbstractSelectionControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.select.MapSelectionControl;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.select.MultipleSelection;
-import org.kie.workbench.common.stunner.core.client.canvas.event.CanvasDrawnEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.ShapeLocationsChangedEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasClearSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.shape.view.ShapeView;
+import org.kie.workbench.common.stunner.core.graph.Element;
 
 import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
 
+/**
+ * Default implementation of a {@link SelectionControl} that supports selection of multiple {@link Element}.
+ * @param <H> {@link AbstractCanvasHandler}
+ */
 @Dependent
 @MultipleSelection
-public final class LienzoMultipleSelectionControl<H extends AbstractCanvasHandler>
+@Default
+public class LienzoMultipleSelectionControl<H extends AbstractCanvasHandler>
         extends AbstractSelectionControl<H> {
 
     private final CursoredSelectionShapeProvider selectionShapeProvider;
@@ -82,39 +90,33 @@ public final class LienzoMultipleSelectionControl<H extends AbstractCanvasHandle
     @Override
     protected void onEnable(final H canvasHandler) {
         super.onEnable(canvasHandler);
-        getWiresManager().enableSelectionManager();
-        getSelectionManager()
-                .setSelectionShapeProvider(selectionShapeProvider);
-        getSelectionManager()
-                .setSelectionListener(selectedItems -> {
-                    final SelectionManager.ChangedItems changedItems = selectedItems.getChanged();
-                    getSelectionControl().deselect(new ArrayList<String>() {{
-                        addAll(shapesToIdentifiers(changedItems.getRemovedShapes().toList()));
-                        addAll(shapesToIdentifiers(changedItems.getRemovedConnectors().toList()));
-                    }});
-                    getSelectionControl().select(new ArrayList<String>() {{
-                        addAll(shapesToIdentifiers(changedItems.getAddedShapes().toList()));
-                        addAll(shapesToIdentifiers(changedItems.getAddedConnectors().toList()));
-                    }});
-                });
+        getWiresManager()
+                .enableSelectionManager()
+                .setSelectionShapeProvider(selectionShapeProvider)
+                .setSelectionListener(selectionListener);
     }
 
+    private final SelectionListener selectionListener = new SelectionListener() {
+
+        private final DefaultSelectionListener defaultSelectionListener = new DefaultSelectionListener();
+
+        @Override
+        public void onChanged(final SelectionManager.SelectedItems selectedItems) {
+            final SelectionManager.ChangedItems changedItems = selectedItems.getChanged();
+            getSelectionControl().deselect(new Lists.Builder<String>()
+                                                   .addAll(shapesToIdentifiers(changedItems.getRemovedShapes().toList()))
+                                                   .addAll(shapesToIdentifiers(changedItems.getRemovedConnectors().toList())).build());
+            getSelectionControl().select(new Lists.Builder<String>()
+                                                 .addAll(shapesToIdentifiers(changedItems.getAddedShapes().toList()))
+                                                 .addAll(shapesToIdentifiers(changedItems.getAddedConnectors().toList())).build());
+            defaultSelectionListener.onChanged(selectedItems);
+        }
+    };
+
     private void rebuildSelectionArea() {
         if (null != selectionShapeProvider.getShape()) {
             getSelectionManager().getSelectedItems().rebuildBoundingBox();
-            // TODO: Here we need to call the drawSelectionShapeForSelection() method, but it's private.
-            // Let's workaroud it - THIS CAN BE REFACTORED ONCE MOVING TO NEXT LIENZO RELEASE.
-            if (getSelectionManager().getSelectedItems().isEmpty()) {
-                return;
-            }
-
-            BoundingBox bbox = getSelectionManager().getSelectedItems().getBoundingBox();
-
-            getSelectionManager().drawSelectionShape(bbox.getX(),
-                                                     bbox.getY(),
-                                                     bbox.getWidth(),
-                                                     bbox.getHeight(),
-                                                     getWiresManager().getLayer().getLayer().getOverLayer());
+            getSelectionManager().drawSelectionShapeForSelection();
         }
     }
 
@@ -136,7 +138,7 @@ public final class LienzoMultipleSelectionControl<H extends AbstractCanvasHandle
             return false;
         }
 
-        return uuids.stream().anyMatch(uuid -> selectedItems.contains(uuid));
+        return uuids.stream().anyMatch(selectedItems::contains);
     }
 
     @Override
@@ -158,21 +160,18 @@ public final class LienzoMultipleSelectionControl<H extends AbstractCanvasHandle
     @Override
     protected void onClearSelection() {
         super.onClearSelection();
-        clear();
-    }
-
-    @Override
-    protected void onDisable() {
-        super.onDisable();
-        clear();
-    }
-
-    private void clear() {
         if (Objects.nonNull(getSelectionControl().getCanvasHandler())) {
             getSelectionManager().clearSelection();
         }
     }
 
+    @Override
+    protected void onDestroy() {
+        getSelectionManager().destroy();
+        selectionShapeProvider.destroy();
+        super.onDestroy();
+    }
+
     private AbstractCanvasHandler getCanvasHandler() {
         return getSelectionControl().getCanvasHandler();
     }
@@ -186,11 +185,10 @@ public final class LienzoMultipleSelectionControl<H extends AbstractCanvasHandle
         return getWiresManager().getSelectionManager();
     }
 
-    void onCanvasDrawn(final @Observes CanvasDrawnEvent event) {
+    void onCanvasSelection(final @Observes CanvasSelectionEvent event) {
         checkNotNull("event",
                      event);
-        if (null != getCanvasHandler() &&
-                getCanvasHandler().getCanvas().equals(event.getCanvas())) {
+        if (Objects.equals(getCanvasHandler(), event.getCanvasHandler())) {
             selectionShapeProvider.moveShapeToTop();
         }
     }
@@ -233,7 +231,7 @@ public final class LienzoMultipleSelectionControl<H extends AbstractCanvasHandle
                             .addNodeMouseEnterHandler(event -> canvasHandlerSupplier.get().getAbstractCanvas().getView().setCursor(AbstractCanvas.Cursors.MOVE));
             mouseExitHandlerReg =
                     provider.getShape()
-                            .addNodeMouseExitHandler(event -> canvasHandlerSupplier.get().getAbstractCanvas().getView().setCursor(AbstractCanvas.Cursors.AUTO));
+                            .addNodeMouseExitHandler(event -> canvasHandlerSupplier.get().getAbstractCanvas().getView().setCursor(AbstractCanvas.Cursors.DEFAULT));
             return this;
         }
 
@@ -248,6 +246,7 @@ public final class LienzoMultipleSelectionControl<H extends AbstractCanvasHandle
                                                       final double height) {
             provider.setSize(width,
                              height);
+            moveShapeToTop();
             return this;
         }
 
@@ -263,6 +262,12 @@ public final class LienzoMultipleSelectionControl<H extends AbstractCanvasHandle
             return this;
         }
 
+        public void destroy() {
+            clear();
+            mouseEnterHandlerReg = null;
+            mouseExitHandlerReg = null;
+        }
+
         public CursoredSelectionShapeProvider moveShapeToTop() {
             if (null != getShape()) {
                 getShape().moveToTop();
