@@ -28,9 +28,10 @@ import org.kie.workbench.common.stunner.client.widgets.presenters.session.Sessio
 import org.kie.workbench.common.stunner.client.widgets.views.WidgetWrapperView;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
+import org.kie.workbench.common.stunner.core.client.canvas.Canvas;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasPanel;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.select.SelectionControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.zoom.ZoomControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.MediatorsControl;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.SelectionControl;
 import org.kie.workbench.common.stunner.core.client.preferences.StunnerPreferencesRegistries;
 import org.kie.workbench.common.stunner.core.client.session.impl.ViewerSession;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
@@ -86,8 +87,8 @@ public class SessionViewerImpl<S extends ViewerSession>
 
     @Override
     @SuppressWarnings("unchecked")
-    public ZoomControl<AbstractCanvas> getZoomControl() {
-        return getSession().getZoomControl();
+    public MediatorsControl<AbstractCanvas> getMediatorsControl() {
+        return getSession().getMediatorsControl();
     }
 
     private S getSession() {
@@ -150,8 +151,8 @@ public class SessionViewerImpl<S extends ViewerSession>
 
         @Override
         @SuppressWarnings("unchecked")
-        public ZoomControl<AbstractCanvas> getZoomControl() {
-            return getSession().getZoomControl();
+        public <C extends Canvas> MediatorsControl<C> getMediatorsControl() {
+            return (MediatorsControl<C>) getSession().getMediatorsControl();
         }
 
         @Override
