@@ -16,13 +16,13 @@
 
 package org.kie.workbench.common.stunner.bpmn.definition;
 
-import java.util.HashSet;
 import java.util.Objects;
 import java.util.Set;
 
 import javax.validation.Valid;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
+import org.kie.soup.commons.util.Sets;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.stunner.bpmn.definition.property.background.BackgroundSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
@@ -54,12 +54,13 @@ public abstract class BaseConnector implements BPMNViewDefinition {
     public static final Double BORDER_SIZE = 1d;
 
     @Labels
-    protected final Set<String> labels = new HashSet<String>() {{
-        add("all");
-        add("lane_child");
-        add("ConnectingObjectsMorph");
-        add("cm_nop");
-    }};
+    protected final Set<String> labels = new Sets.Builder<String>()
+            .add("all")
+            .add("lane_child")
+            .add("ConnectingObjectsMorph")
+            .add("cm_nop")
+            .add("connector")
+            .build();
 
     protected BaseConnector() {
     }
@@ -107,10 +108,11 @@ public abstract class BaseConnector implements BPMNViewDefinition {
 
     @Override
     public int hashCode() {
-        return HashUtil.combineHashCodes(general.hashCode(),
-                                         backgroundSet.hashCode(),
-                                         fontSet.hashCode(),
-                                         labels.hashCode());
+        return HashUtil.combineHashCodes(Objects.hashCode(getClass()),
+                                         Objects.hashCode(general),
+                                         Objects.hashCode(backgroundSet),
+                                         Objects.hashCode(fontSet),
+                                         Objects.hashCode(labels));
     }
 
     @Override
