@@ -39,6 +39,7 @@ import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;
 import org.jboss.drools.DroolsPackage;
 import org.jboss.drools.impl.DroolsFactoryImpl;
 import org.jboss.drools.impl.DroolsPackageImpl;
+import org.kie.workbench.common.stunner.bpmn.backend.converters.Result;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.TypedFactoryManager;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.ConverterFactory;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.DefinitionsBuildingContext;
@@ -50,7 +51,7 @@ import org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.Defini
 import org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.GraphBuilder;
 import org.kie.workbench.common.stunner.bpmn.backend.resource.JBPMBpmn2Resource;
 import org.kie.workbench.common.stunner.bpmn.backend.resource.JBPMBpmn2ResourceFactory;
-import org.kie.workbench.common.stunner.bpmn.backend.workitem.service.WorkItemDefinitionBackendService;
+import org.kie.workbench.common.stunner.bpmn.workitem.service.WorkItemDefinitionLookupService;
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
 import org.kie.workbench.common.stunner.core.api.FactoryManager;
 import org.kie.workbench.common.stunner.core.backend.service.XMLEncoderDiagramMetadataMarshaller;
@@ -63,10 +64,20 @@ import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.command.GraphCommandManager;
 import org.kie.workbench.common.stunner.core.graph.command.impl.GraphCommandFactory;
 import org.kie.workbench.common.stunner.core.graph.content.definition.DefinitionSet;
+import org.kie.workbench.common.stunner.core.marshaller.MarshallingMessage;
+import org.kie.workbench.common.stunner.core.marshaller.MarshallingRequest;
+import org.kie.workbench.common.stunner.core.marshaller.MarshallingResponse;
 import org.kie.workbench.common.stunner.core.rule.RuleManager;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+/*
+ * "Direct" in the name "BaseDirectDiagramMarshaller" means "skipping json encoding".
+ * The old BPMNDiagramMarshaller went through an additional step converting XML into JSON for legacy reasons.
+ * The reason for the new version, beside a necessary spring cleaning, was to remove this extra step.
+ * So the new version is "Direct" as in "it doesn't go through the extra step".
+ *
+ */
 public abstract class BaseDirectDiagramMarshaller implements DiagramMarshaller<Graph, Metadata, Diagram<Graph, Metadata>> {
 
     private static final Logger LOG = LoggerFactory.getLogger(BaseDirectDiagramMarshaller.class);
@@ -74,7 +85,7 @@ public abstract class BaseDirectDiagramMarshaller implements DiagramMarshaller<G
     private final XMLEncoderDiagramMetadataMarshaller diagramMetadataMarshaller;
     private final DefinitionManager definitionManager;
     private final RuleManager ruleManager;
-    private final WorkItemDefinitionBackendService workItemDefinitionService;
+    private final WorkItemDefinitionLookupService workItemDefinitionService;
     protected final TypedFactoryManager typedFactoryManager;
     private final GraphCommandFactory commandFactory;
     private final GraphCommandManager commandManager;
@@ -82,7 +93,7 @@ public abstract class BaseDirectDiagramMarshaller implements DiagramMarshaller<G
     public BaseDirectDiagramMarshaller(final XMLEncoderDiagramMetadataMarshaller diagramMetadataMarshaller,
                                        final DefinitionManager definitionManager,
                                        final RuleManager ruleManager,
-                                       final WorkItemDefinitionBackendService workItemDefinitionService,
+                                       final WorkItemDefinitionLookupService workItemDefinitionService,
                                        final FactoryManager factoryManager,
                                        final GraphCommandFactory commandFactory,
                                        final GraphCommandManager commandManager) {
@@ -137,8 +148,20 @@ public abstract class BaseDirectDiagramMarshaller implements DiagramMarshaller<G
     }
 
     @Override
-    public Graph<DefinitionSet, Node> unmarshall(final Metadata metadata,
-                                                 final InputStream inputStream) throws IOException {
+    public Graph unmarshall(Metadata metadata, InputStream input) {
+        MarshallingResponse<Graph> marshallingResponse = unmarshallWithValidation(MarshallingRequest.builder()
+                                                                                          .metadata(metadata)
+                                                                                          .input(input)
+                                                                                          .mode(MarshallingRequest.Mode.ERROR)
+                                                                                          .build());
+        return marshallingResponse.getResult();
+    }
+
+    @Override
+    public MarshallingResponse<Graph> unmarshallWithValidation(MarshallingRequest<InputStream, Metadata> request) {
+        final Metadata metadata = request.getMetadata();
+        final InputStream inputStream = request.getInput();
+
         LOG.debug("Starting diagram unmarshalling...");
 
         DefinitionResolver definitionResolver;
@@ -147,42 +170,60 @@ public abstract class BaseDirectDiagramMarshaller implements DiagramMarshaller<G
             final DefinitionsHandler definitionsHandler = parseDefinitions(inputStream);
             definitionResolver = new DefinitionResolver(definitionsHandler.getDefinitions(),
                                                         workItemDefinitionService.execute(metadata),
-                                                        definitionsHandler.isJbpm());
+                                                        definitionsHandler.isJbpm(),
+                                                        request.getMode());
+
+            metadata.setCanvasRootUUID(definitionResolver.getDefinitions().getId());
+            metadata.setTitle(definitionResolver.getProcess().getName());
+
+            BaseConverterFactory converterFactory = createToStunnerConverterFactory(definitionResolver, typedFactoryManager);
+
+            // perform actual conversion. Process is the root of the diagram
+            Result<BpmnNode> result = converterFactory.rootProcessConverter().convertProcess();
+
+            BpmnNode diagramRoot = result.value();
+
+            LOG.debug("Diagram unmarshalling completed successfully.");
+
+            // the root node contains all of the information
+            // needed to build the entire graph (including parent/child relationships)
+            // thus, we can now walk the graph to issue all the commands
+            // to draw it on our canvas
+            Diagram<Graph<DefinitionSet, Node>, Metadata> diagram =
+                    typedFactoryManager.newDiagram(
+                            definitionResolver.getDefinitions().getId(),
+                            getDefinitionSetClass(),
+                            metadata);
+            Graph<DefinitionSet, Node> graph = diagram.getGraph();
+            GraphBuilder graphBuilder =
+                    new GraphBuilder(
+                            graph,
+                            definitionManager,
+                            typedFactoryManager,
+                            ruleManager,
+                            commandFactory,
+                            commandManager);
+            graphBuilder.render(diagramRoot);
+
+            LOG.debug("Diagram drawing completed successfully for:" + request);
+            return MarshallingResponse.builder()
+                    .state(MarshallingResponse.State.SUCCESS)
+                    .messages(result.messages())
+                    .result(graph)
+                    .build();
+        } catch (Exception e) {
+            LOG.error("Marshalling error.", e);
+            return MarshallingResponse.builder()
+                    .state(MarshallingResponse.State.ERROR)
+                    .addMessage(MarshallingMessage.builder().message(e.getMessage()).build())
+                    .build();
         } finally {
-            inputStream.close();
+            try {
+                inputStream.close();
+            } catch (IOException e) {
+                throw new RuntimeException("Error closing inputStream for: " + request, e);
+            }
         }
-
-        metadata.setCanvasRootUUID(definitionResolver.getDefinitions().getId());
-        metadata.setTitle(definitionResolver.getProcess().getName());
-
-        BaseConverterFactory converterFactory = createToStunnerConverterFactory(definitionResolver, typedFactoryManager);
-
-        // perform actual conversion. Process is the root of the diagram
-        BpmnNode diagramRoot = converterFactory.rootProcessConverter().convertProcess();
-
-        LOG.debug("Diagram unmarshalling completed successfully.");
-
-        // the root node contains all of the information
-        // needed to build the entire graph (including parent/child relationships)
-        // thus, we can now walk the graph to issue all the commands
-        // to draw it on our canvas
-        Diagram<Graph<DefinitionSet, Node>, Metadata> diagram =
-                typedFactoryManager.newDiagram(
-                        definitionResolver.getDefinitions().getId(),
-                        getDefinitionSetClass(),
-                        metadata);
-        GraphBuilder graphBuilder =
-                new GraphBuilder(
-                        diagram.getGraph(),
-                        definitionManager,
-                        typedFactoryManager,
-                        ruleManager,
-                        commandFactory,
-                        commandManager);
-        graphBuilder.render(diagramRoot);
-
-        LOG.debug("Diagram drawing completed successfully.");
-        return diagram.getGraph();
     }
 
     private Bpmn2Resource createBpmn2Resource() {
