@@ -20,13 +20,20 @@ import org.eclipse.bpmn2.FormalExpression;
 import org.eclipse.bpmn2.MultiInstanceLoopCharacteristics;
 import org.eclipse.bpmn2.SubProcess;
 import org.junit.Test;
+import org.kie.workbench.common.stunner.bpmn.backend.converters.customproperties.CustomElement;
+import org.kie.workbench.common.stunner.bpmn.definition.property.general.SLADueDate;
 
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatCode;
+import static org.junit.Assert.assertTrue;
 import static org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.Factories.bpmn2;
 
 public class MultipleInstanceSubProcessPropertyWriterTest {
 
+    private MultipleInstanceSubProcessPropertyWriter tested =
+            new MultipleInstanceSubProcessPropertyWriter(bpmn2.createSubProcess(),
+                                                         new FlatVariableScope());
+
     @Test
     public void nullInputOutputsShouldNotThrow() {
         SubProcess subProcess = bpmn2.createSubProcess();
@@ -37,8 +44,8 @@ public class MultipleInstanceSubProcessPropertyWriterTest {
         assertThatCode(() -> {
             p.setInput(null);
             p.setOutput(null);
-            p.createDataInput(null);
-            p.createDataOutput(null);
+            p.createDataInput(null, null);
+            p.createDataOutput(null, null);
             p.setCompletionCondition(null);
         }).doesNotThrowAnyException();
     }
@@ -46,7 +53,7 @@ public class MultipleInstanceSubProcessPropertyWriterTest {
     @Test
     public void completionConditionMustBeWrappedInCdata() {
         String expression = "x<1";
-        String expected = "x&lt;1";
+        String expected = "<![CDATA[" + expression + "]]>";
         SubProcess subProcess = bpmn2.createSubProcess();
         MultipleInstanceSubProcessPropertyWriter p =
                 new MultipleInstanceSubProcessPropertyWriter(
@@ -59,4 +66,18 @@ public class MultipleInstanceSubProcessPropertyWriterTest {
 
         assertThat(expected).isEqualTo(completionCondition.getBody());
     }
+
+    @Test
+    public void testSetIsAsync() {
+        tested.setAsync(Boolean.TRUE);
+        assertTrue(CustomElement.async.of(tested.getFlowElement()).get());
+    }
+
+    @Test
+    public void testSetSlaDueDate() {
+        String slaDueDate = "12/25/1983";
+        tested.setSlaDueDate(new SLADueDate(slaDueDate));
+
+        assertTrue(CustomElement.slaDueDate.of(tested.getFlowElement()).get().contains(slaDueDate));
+    }
 }
\ No newline at end of file
