@@ -78,10 +78,13 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
             "System.out.println(\"`&(^*&^(\\n\\r\");\n" +
             "Object o = kcontext.getVariable(\"hello_world\");";
 
+    private static final String SLA_DUE_DATE = "12/25/1983";
+
     public MultipleInstanceSubProcessTest() throws Exception {
     }
 
     @Test
+    @Override
     public void testUnmarshallTopLevelEmptyPropertiesSubProcess() {
         Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
@@ -102,11 +105,13 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
                                                      EMPTY_VALUE,
                                                      SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
                                                      EMPTY_VALUE,
-                                                     SUBPROCESS_SCRIPT_JAVA_LANGUAGE);
+                                                     SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
+                                                     EMPTY_VALUE);
         assertSubProcessProcessData(topLevelSubProcess.getProcessData(), EMPTY_VALUE);
     }
 
     @Test
+    @Override
     public void testUnmarshallTopLevelFilledPropertiesSubProcess() {
         final String SUB_PROCESS_NAME_JAVA = "Multiple Instance sub-process01 name ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
         final String SUB_PROCESS_DOCUMENTATION_JAVA = "Multiple Instance sub-process01 doc\n ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
@@ -115,9 +120,9 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
         final String SUB_PROCESS_NAME_MVEL = "Multiple Instance sub-process03 name ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
         final String SUB_PROCESS_DOCUMENTATION_MVEL = "Multiple Instance sub-process03 doc\n ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
 
-        final String SUB_PROCESS_VARIABLES_JAVA = "subVar01:String";
-        final String SUB_PROCESS_VARIABLES_JAVASCRIPT = "subVar02:String";
-        final String SUB_PROCESS_VARIABLES_MVEL = "subVarCustom:any.Custom,subVarBoolean:Boolean,subVarFloat:Float,subVarInteger:Integer,subVarObject:Object,subVarString:String";
+        final String SUB_PROCESS_VARIABLES_JAVA = "subVar01:String:false";
+        final String SUB_PROCESS_VARIABLES_JAVASCRIPT = "subVar02:String:false";
+        final String SUB_PROCESS_VARIABLES_MVEL = "subVarCustom:any.Custom:false,subVarBoolean:Boolean:false,subVarFloat:Float:false,subVarInteger:Integer:false,subVarObject:Object:false,subVarString:String:false";
 
         Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
@@ -138,7 +143,8 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
                                                      SUBPROCESS_ON_ENTRY_ACTION_JAVA,
                                                      SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
                                                      SUBPROCESS_ON_EXIT_ACTION_JAVA,
-                                                     SUBPROCESS_SCRIPT_JAVA_LANGUAGE);
+                                                     SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
+                                                     SLA_DUE_DATE);
         assertSubProcessProcessData(topLevelSubProcessJava.getProcessData(), SUB_PROCESS_VARIABLES_JAVA);
 
         MultipleInstanceSubprocess topLevelSubProcessJavascript = getSubProcessNodeById(diagram,
@@ -157,7 +163,8 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
                                                      SUBPROCESS_ON_ENTRY_ACTION_JAVASCRIPT,
                                                      SUBPROCESS_SCRIPT_JAVASCRIPT_LANGUAGE,
                                                      SUBPROCESS_ON_EXIT_ACTION_JAVASCRIPT,
-                                                     SUBPROCESS_SCRIPT_JAVASCRIPT_LANGUAGE);
+                                                     SUBPROCESS_SCRIPT_JAVASCRIPT_LANGUAGE,
+                                                     SLA_DUE_DATE);
         assertSubProcessProcessData(topLevelSubProcessJavascript.getProcessData(), SUB_PROCESS_VARIABLES_JAVASCRIPT);
 
         MultipleInstanceSubprocess topLevelSubProcessMVEL = getSubProcessNodeById(diagram,
@@ -176,11 +183,13 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
                                                      SUBPROCESS_ON_ENTRY_ACTION_MVEL,
                                                      SUBPROCESS_SCRIPT_MVEL_LANGUAGE,
                                                      SUBPROCESS_ON_EXIT_ACTION_MVEL,
-                                                     SUBPROCESS_SCRIPT_MVEL_LANGUAGE);
+                                                     SUBPROCESS_SCRIPT_MVEL_LANGUAGE,
+                                                     SLA_DUE_DATE);
         assertSubProcessProcessData(topLevelSubProcessMVEL.getProcessData(), SUB_PROCESS_VARIABLES_MVEL);
     }
 
     @Test
+    @Override
     public void testUnmarshallTopLevelSubProcessWithEdges() {
         final String SUB_PROCESS_NAME = "Multiple Instance Sub-process07";
 
@@ -203,11 +212,13 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
                                                      EMPTY_VALUE,
                                                      SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
                                                      EMPTY_VALUE,
-                                                     SUBPROCESS_SCRIPT_JAVA_LANGUAGE);
+                                                     SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
+                                                     EMPTY_VALUE);
         assertSubProcessProcessData(topLevelSubProcess.getProcessData(), EMPTY_VALUE);
     }
 
     @Test
+    @Override
     public void testUnmarshallSubProcessLevelEmptyPropertiesSubProcess() {
         Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
@@ -228,11 +239,13 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
                                                      EMPTY_VALUE,
                                                      SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
                                                      EMPTY_VALUE,
-                                                     SUBPROCESS_SCRIPT_JAVA_LANGUAGE);
+                                                     SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
+                                                     EMPTY_VALUE);
         assertSubProcessProcessData(subProcessLevelSubProcess.getProcessData(), EMPTY_VALUE);
     }
 
     @Test
+    @Override
     public void testUnmarshallSubProcessLevelFilledPropertiesSubProcess() {
         final String SUB_PROCESS_NAME_JAVA = "Multiple Instance sub-process04 name ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
         final String SUB_PROCESS_DOCUMENTATION_JAVA = "Multiple Instance sub-process04 doc\n ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
@@ -241,9 +254,9 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
         final String SUB_PROCESS_NAME_MVEL = "Multiple Instance sub-process06 name ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
         final String SUB_PROCESS_DOCUMENTATION_MVEL = "Multiple Instance sub-process06 doc\n ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
 
-        final String SUB_PROCESS_VARIABLES_JAVA = "subVar04:String";
-        final String SUB_PROCESS_VARIABLES_JAVASCRIPT = "subVar05:String";
-        final String SUB_PROCESS_VARIABLES_MVEL = "subVarCustom:any.Custom,subVarBoolean:Boolean,subVarFloat:Float,subVarInteger:Integer,subVarObject:Object,subVarString:String";
+        final String SUB_PROCESS_VARIABLES_JAVA = "subVar04:String:false";
+        final String SUB_PROCESS_VARIABLES_JAVASCRIPT = "subVar05:String:false";
+        final String SUB_PROCESS_VARIABLES_MVEL = "subVarCustom:any.Custom:false,subVarBoolean:Boolean:false,subVarFloat:Float:false,subVarInteger:Integer:false,subVarObject:Object:false,subVarString:String:false";
 
         Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
@@ -264,7 +277,8 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
                                                      SUBPROCESS_ON_ENTRY_ACTION_JAVA,
                                                      SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
                                                      SUBPROCESS_ON_EXIT_ACTION_JAVA,
-                                                     SUBPROCESS_SCRIPT_JAVA_LANGUAGE);
+                                                     SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
+                                                     SLA_DUE_DATE);
         assertSubProcessProcessData(subProcessLevelSubProcessJava.getProcessData(), SUB_PROCESS_VARIABLES_JAVA);
 
         MultipleInstanceSubprocess subProcessLevelSubProcessJavascript = getSubProcessNodeById(diagram,
@@ -283,7 +297,8 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
                                                      SUBPROCESS_ON_ENTRY_ACTION_JAVASCRIPT,
                                                      SUBPROCESS_SCRIPT_JAVASCRIPT_LANGUAGE,
                                                      SUBPROCESS_ON_EXIT_ACTION_JAVASCRIPT,
-                                                     SUBPROCESS_SCRIPT_JAVASCRIPT_LANGUAGE);
+                                                     SUBPROCESS_SCRIPT_JAVASCRIPT_LANGUAGE,
+                                                     SLA_DUE_DATE);
         assertSubProcessProcessData(subProcessLevelSubProcessJavascript.getProcessData(), SUB_PROCESS_VARIABLES_JAVASCRIPT);
 
         MultipleInstanceSubprocess subProcessLevelSubProcessMVEL = getSubProcessNodeById(diagram,
@@ -302,11 +317,13 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
                                                      SUBPROCESS_ON_ENTRY_ACTION_MVEL,
                                                      SUBPROCESS_SCRIPT_MVEL_LANGUAGE,
                                                      SUBPROCESS_ON_EXIT_ACTION_MVEL,
-                                                     SUBPROCESS_SCRIPT_MVEL_LANGUAGE);
+                                                     SUBPROCESS_SCRIPT_MVEL_LANGUAGE,
+                                                     SLA_DUE_DATE);
         assertSubProcessProcessData(subProcessLevelSubProcessMVEL.getProcessData(), SUB_PROCESS_VARIABLES_MVEL);
     }
 
     @Test
+    @Override
     public void testUnmarshallSubProcessLevelSubProcessWithEdges() {
         final String SUB_PROCESS_NAME = "Multiple Instance Sub-process08";
 
@@ -329,7 +346,8 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
                                                      EMPTY_VALUE,
                                                      SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
                                                      EMPTY_VALUE,
-                                                     SUBPROCESS_SCRIPT_JAVA_LANGUAGE);
+                                                     SUBPROCESS_SCRIPT_JAVA_LANGUAGE,
+                                                     EMPTY_VALUE);
         assertSubProcessProcessData(subProcessLevelSubProcess.getProcessData(), EMPTY_VALUE);
     }
 
@@ -387,14 +405,17 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
                                                               String onEntryActionScriptValue,
                                                               String onEntryActionScriptLanguage,
                                                               String onExitActionScriptValue,
-                                                              String onExitActionScriptLanguage) {
+                                                              String onExitActionScriptLanguage,
+                                                              String slaDueDate) {
         assertThat(executionSet).isNotNull();
+
         assertThat(executionSet.getMultipleInstanceCollectionInput()).isNotNull();
         assertThat(executionSet.getMultipleInstanceCollectionOutput()).isNotNull();
         assertThat(executionSet.getMultipleInstanceDataInput()).isNotNull();
         assertThat(executionSet.getMultipleInstanceDataOutput()).isNotNull();
         assertThat(executionSet.getMultipleInstanceCompletionCondition()).isNotNull();
         assertThat(executionSet.getIsAsync()).isNotNull();
+        assertThat(executionSet.getSlaDueDate()).isNotNull();
 
         assertThat(executionSet.getOnEntryAction()).isNotNull();
         assertThat(executionSet.getOnExitAction()).isNotNull();
@@ -416,6 +437,7 @@ public class MultipleInstanceSubProcessTest extends SubProcessTest<MultipleInsta
         assertThat(executionSet.getMultipleInstanceCompletionCondition().getValue()).isEqualTo(multipleInstanceCompletionCondition);
 
         assertThat(executionSet.getIsAsync().getValue()).isEqualTo(isAsync);
+        assertThat(executionSet.getSlaDueDate().getValue()).isEqualTo(slaDueDate);
 
         assertThat(onEntryScriptTypeValues.get(0).getScript()).isEqualTo(onEntryActionScriptValue);
         assertThat(onEntryScriptTypeValues.get(0).getLanguage()).isEqualTo(onEntryActionScriptLanguage);
