@@ -25,9 +25,13 @@ import org.eclipse.bpmn2.Definitions;
 import org.eclipse.bpmn2.FormalExpression;
 import org.eclipse.bpmn2.Process;
 import org.eclipse.bpmn2.Property;
+import org.eclipse.bpmn2.StartEvent;
 import org.junit.Test;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.DefinitionsConverter;
-import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.marshalling.BPMNDiagramMarshallerBase;
+import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.Ids;
+import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.properties.CatchEventPropertyWriter;
+import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.properties.FlatVariableScope;
+import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.marshalling.BPMNDiagramMarshallerBaseTest;
 import org.kie.workbench.common.stunner.bpmn.definition.UserTask;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.AssignmentsInfo;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
@@ -37,8 +41,9 @@ import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 
 import static junit.framework.TestCase.assertEquals;
+import static org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.Factories.bpmn2;
 
-public class AssociationsTest extends BPMNDiagramMarshallerBase {
+public class AssociationsTest extends BPMNDiagramMarshallerBaseTest {
 
     private static final String BPMN_FILE_PATH = "org/kie/workbench/common/stunner/bpmn/backend/service/diagram/associationsAndAssignments.bpmn";
     private static final String TASK_ID = "_5E1F51EC-B398-4BF7-B32D-45FB6CE4731A";
@@ -48,8 +53,9 @@ public class AssociationsTest extends BPMNDiagramMarshallerBase {
     }
 
     @Test
+    @SuppressWarnings("unchecked")
     public void parseAssociations() throws Exception {
-        Diagram<Graph, Metadata> d = unmarshall(newMarshaller, BPMN_FILE_PATH);
+        Diagram<Graph, Metadata> d = unmarshall(marshaller, BPMN_FILE_PATH);
         Node<View<UserTask>, ?> node = d.getGraph().getNode(TASK_ID);
         UserTask definition = node.getContent().getDefinition();
         AssignmentsInfo assignmentsinfo = definition.getExecutionSet().getAssignmentsinfo();
@@ -57,12 +63,27 @@ public class AssociationsTest extends BPMNDiagramMarshallerBase {
                      assignmentsinfo.getValue());
     }
 
+    @Test
+    public void marshallUnassignedDeclaration() {
+        String id = "PARENT";
+        String decl = "||Foo:String||";
+        StartEvent startEvent = bpmn2.createStartEvent();
+        startEvent.setId(id);
+        CatchEventPropertyWriter p =
+                new CatchEventPropertyWriter(startEvent, new FlatVariableScope());
+        p.setAssignmentsInfo(new AssignmentsInfo(decl));
+
+        assertEquals(1, p.getItemDefinitions().size());
+        assertEquals(Ids.dataOutputItem(id, "Foo"), p.getItemDefinitions().get(0).getId());
+        assertEquals("String", p.getItemDefinitions().get(0).getStructureRef());
+        assertEquals(1, startEvent.getDataOutputs().size());
+        assertEquals("Foo", startEvent.getDataOutputs().get(0).getName());
+        assertEquals(0, startEvent.getDataOutputAssociation().size());
+    }
+
     @Test
     public void marshallAssociations() throws Exception {
-        Diagram<Graph, Metadata> d = unmarshall(newMarshaller, BPMN_FILE_PATH);
-        Node<View<UserTask>, ?> node = d.getGraph().getNode(TASK_ID);
-        UserTask definition = node.getContent().getDefinition();
-        AssignmentsInfo assignmentsinfo = definition.getExecutionSet().getAssignmentsinfo();
+        Diagram<Graph, Metadata> d = unmarshall(marshaller, BPMN_FILE_PATH);
 
         DefinitionsConverter definitionsConverter =
                 new DefinitionsConverter(d.getGraph());
@@ -78,7 +99,7 @@ public class AssociationsTest extends BPMNDiagramMarshallerBase {
         assertEquals("<![CDATA[HELLO]]>", findAssignment(associations, "Body"));
     }
 
-    public String findVar(List<DataInputAssociation> associations, String varName) {
+    private String findVar(List<DataInputAssociation> associations, String varName) {
         return associations.stream()
                 .filter(a -> {
                     DataInput in = (DataInput) a.getTargetRef();
@@ -92,7 +113,7 @@ public class AssociationsTest extends BPMNDiagramMarshallerBase {
                 .get();
     }
 
-    public String findAssignment(List<DataInputAssociation> associations, String varName) {
+    private String findAssignment(List<DataInputAssociation> associations, String varName) {
         return associations.stream()
                 .filter(a -> {
                     DataInput in = (DataInput) a.getTargetRef();
