@@ -16,7 +16,9 @@
 
 package org.kie.workbench.common.stunner.cm.client.command;
 
+import java.util.Collections;
 import java.util.Optional;
+import java.util.OptionalInt;
 
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
@@ -96,9 +98,10 @@ public class CaseManagementCanvasCommandFactoryTest {
         //Checks the command is a specific sub-class for Case Management
         final CanvasCommand<AbstractCanvasHandler> command = factory.setChildNode(parent,
                                                                                   child,
-                                                                                  Optional.of(0),
                                                                                   Optional.empty(),
-                                                                                  Optional.empty());
+                                                                                  OptionalInt.of(0),
+                                                                                  Optional.empty(),
+                                                                                  OptionalInt.empty());
         assertNotNull(command);
         assertTrue(command instanceof CaseManagementSetChildCommand);
     }
@@ -113,6 +116,7 @@ public class CaseManagementCanvasCommandFactoryTest {
     }
 
     @Test
+    @SuppressWarnings("unchecked")
     public void checkUpdatePositionCommandType() {
         //Checks the command is a specific sub-class for Case Management
         final CanvasCommand<AbstractCanvasHandler> command = factory.updatePosition(child,
@@ -120,4 +124,37 @@ public class CaseManagementCanvasCommandFactoryTest {
         assertNotNull(command);
         assertTrue(command instanceof CaseManagementUpdatePositionCommand);
     }
+
+    @Test
+    public void checkDelete() {
+        final CanvasCommand<AbstractCanvasHandler> command = factory.delete(Collections.singletonList(child));
+
+        assertNotNull(command);
+        assertTrue(command instanceof CaseManagementDeleteElementsCommand);
+    }
+
+    @Test
+    public void checkDeleteNode() {
+        final CanvasCommand<AbstractCanvasHandler> command = factory.deleteNode(child);
+
+        assertNotNull(command);
+        assertTrue(command instanceof CaseManagementDeleteNodeCommand);
+    }
+
+    @Test
+    public void checkAddNode() {
+        final CanvasCommand<AbstractCanvasHandler> command = factory.addNode(child,
+                                                                             CaseManagementShapeSet.class.getName());
+
+        assertNotNull(command);
+        assertTrue(command instanceof CaseManagementAddNodeCommand);
+    }
+
+    @Test
+    public void checkClearCanvas() {
+        final CanvasCommand<AbstractCanvasHandler> command = factory.clearCanvas();
+
+        assertNotNull(command);
+        assertTrue(command instanceof CaseManagementClearCommand);
+    }
 }
